/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_EQ_HPP_
#define _HEAVY_CONTEXT_WSTD_EQ_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvControlSystem.h"
#include "HvControlSlice.h"
#include "HvSignalLine.h"
#include "HvControlCast.h"
#include "HvControlVar.h"
#include "HvSignalBiquad.h"
#include "HvControlBinop.h"
#include "HvMath.h"
#include "HvControlIf.h"
#include "HvSignalVar.h"
#include "HvControlUnop.h"

class Heavy_WSTD_EQ : public HeavyContext {

 public:
  Heavy_WSTD_EQ(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_EQ();

  const char *getName() override { return "WSTD_EQ"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        HIGH = 0xC9CE7B11, // High
        LOW = 0x87744544, // Low
        MID = 0xBFDC48B6, // Mid
        MID_FREQ = 0x59CF21AC, // Mid_Freq
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_PWJqKuvd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_1P2bf5un_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Jmqtqx4g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_RppIX3ln_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_hvKdBgPi_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_aCp6KRCU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_BKPojZDl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_eYh4AZzE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Uq9Nxydp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_CdLjdEai_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_IUiJaBar_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZrWicJDo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qRSFyRCa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mskdXvY5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_smuCxYay_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7RGVrHkC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mzZQ44eQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IERp80rz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_oZh9tmvy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QLgREsH3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_YAoxtByJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_X4yHB9vd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BVPTYRb0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MQNZPY9t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ntuQ5vXw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PkVGKVSp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6XAgPfQF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_E2C6Vn1V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_29bHStIy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GsBBdmJO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BPi11I13_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_5gHgH7rf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_LMmoWdWu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_f66vy9vk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tJ7IjlqA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pDGSVpSw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_c7y1t7HZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_I7a4W1p5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PWOzEYkR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1YJEOzi2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kIr998Nh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_K5FmRsO8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Zs4oovv8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_pm467h5M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lxbFWm5Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HiGSqDUe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CfjRG7OZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_puOCoAHl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nDI0kDoG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1JjqI8pS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ABDcoKFa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UxQeHFcg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UZ1kiLqE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kdtbrG6R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Hs24rtUk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_HMiZzIJ6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_aVk16EWi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eSQ1MWhQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UzahQOIz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BFo7y5NC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QDGnMJCj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gXQ7pUYV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_i0Ka9O4v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_G5l1H9LM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tVvxCTXw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qGPlTl71_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_VVmbnxtS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5Mv91S7v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9n5A6BOw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fhYQEV2Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_c5afwIDh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bNlYgjT1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HqchzYvK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dqBUQKm8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xpyccycD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nFnpfDVf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lxmy60Bu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_uPRoKRJD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_miXh3fzr_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_zG4kQ4wA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_9ZJ9yCuO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_93l9BUbM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_nTfFK86M_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_fixKJoBa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_kFBTKeDq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_qB3BZiWv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_jerBwwDl_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_1ztBVtJ3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_kGWrsWMl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_MVmHiNH0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_bUIICF0U_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_urhSFCu6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_j8IM3GUT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_DZUuMThg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fvOnQk0B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Vayi6Xrb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8IyLDjKz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eLkfIfbQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ESvws7Br_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_koBq9WKi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_RLwayXtK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_nkBYAUU0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PBlAlABe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MbBGleJR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Q6u6bCJB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uiF3Ad0m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gRtp6cES_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_qkbBtE8A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_Nk7nhqIo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9uwweRxm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_csTLhh41_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lnvf6ogf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ShYTXadJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sz2w5avU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_FVnVrgNu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gu8HDPDk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_b6zFpDn0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gHfSNQxB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1rzGKKGS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_e77hoSlT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qInCdKXv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nqf4vY32_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9N4O6wZO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Z5CX7UHZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_y8I1N6EF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_VGNL7JWA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JjIGIKIs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PTGckmZw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_B9yKh2MQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_C5PiJnuT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_B3kCx9w3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xrZ3bSnk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9BuJR6Bl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iFlSXTlc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NTIEL4ut_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hpMUqsGa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_O6Bwiwcl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_P1y8nhsl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_08AJOOgR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IfShY5IG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Yg2EVIFE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XLTPrbd7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZGhQjOIZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3qYys916_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Py242o26_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZiQwMp9R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EoRbkOpZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HgDKLgZG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XQfPUM99_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vg15mao9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BYeu5h76_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ympJpjrf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SkngodKH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Dml4hLbo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4hOYCczX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7iYsiTDz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_v9WuaQq3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_IVwIsh12_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_ziRL9k5U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XDnakHGJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CsvnRpNs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8ewlGY91_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OqqGIoa4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_X6HC7PEp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_KnxrdPUg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_8g94BvNV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WZwFcVPN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_q1192zkr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XZYdbgNG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ijRxh2Qm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ivKVU9hU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_M2YeMXmy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ChJoGFEz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fK4DeXBp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RZfVsQcK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_sGyn2Bmm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_JHkNQcJ7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_pPJVD8dD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_b79EWyj5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LnXBgtSI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_ldRYAxNc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_HL7OUOBs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_BISDXd6P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PDXQf1zt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aq31QjE6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ExjYmQyh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ho7xzF5m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XrRldhdJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_je7cRxeg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5qp36wL2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GhuNRszk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_y6vKHAFv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0NbIofUe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VTYzPGdA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_C223am0Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CdF2t0u5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_s7dsob64_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FMPKPs6P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qohWaemW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qQivOeoV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_l2FjmrwZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3kZyhQhS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WlnyT9XA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YNpGQPQu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_g14Ssnn2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fY1NJHgc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Hik5Os4x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Y3VqARlF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_hhFIkFby_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ckCCNf7J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YSUDesL6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tG22Rc50_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NflAqDU9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pvzzk1Jv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_r0ANmhyM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_lA8Eubzx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_69cqrMAA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LXiF8V4C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NqfdLwVI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ty1zfM8r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Lqf1BRAU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_y9vHIOBi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Tjkx19Si_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5gIlEmJN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_udfCmfes_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kEBAYqJH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JoduXMLD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aGDcMyob_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OoGuCtkT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_V87I52Nm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mFigPqak_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_v7aubxeB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_K70tnFY0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_mrmCqZyC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_GgrixTeC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Om2Zq2Ql_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jmTzalDt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_qJf8gLKh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_qD1340gg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_3cRiLGKb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_p6u9OYmq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uDoaCVmw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_82lF8XfF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_f1C9ddNa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_l1PLRDj8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KCEInLV2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_F0sCoDh0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_r5JwsTzS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LDMKW4E2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GhVnCHbz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3qxFjXV8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iWrcyNtT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HHLZijH6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JZ2IbmPb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1US3xU1X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xbO8UY1M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Pds1VhFr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PJmuOAz0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6jRMMuFj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9ieq6Bia_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_a6vpCrwn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SIRcOFtp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ySWPHXxI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0bDQmt97_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WfeFWxVz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_mFDdla3a_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_mZBjAowe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_qBMhzFFC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_IL0FwYpR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_s96Fqr7Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_0UtEqoqx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_N1aKhsEN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VZ6vrjC2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eEGy39ti_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fIgsWAMy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xcuxBDot_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Tw95VNKu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eFrxa5M3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tYw1HkZx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8ML2gCYt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KrNfMpZC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_saYtiXHE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_R1vXKtgE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TvZfOHxY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TCXFgzve_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FQB7WwWv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZPCKlTXA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EGTYLAKn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6vqXlB2D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FDTV2AK1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_aehEHtCn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VQxGYpQK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_eMjhq3vb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_QktBtJc3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_BaOFXrbT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1PwQ0oxK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LwqJV6lh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xh6UiQsM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gKP27BMb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Drt7L67e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hTjoSmQq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NfgDeXdx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yD8PGftt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sctt6K4F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_3PN28CfP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yQf09ajf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hvvWxsgO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nXJkehwv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qxGU4vEG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cg7iDwdG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_P2WOz98B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_y9BGHwoY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mxyIEMke_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_a08Ix1gh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bSC581HO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_buzwHiRa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_m5xDDkXC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_gBfm3WqP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iNufwB7Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ODu4ta5w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JBlJ2XCw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wA0oQ3TN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pxf2b0MP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ElkHX3bX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LRRnzXFm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tvcXa7Gg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_txvt30av_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Omf6faGA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_r1yWoVjZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ds8AAdIt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gV2HrKzp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PEZNuajI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qzcIBqra_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ffXoGqen_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_G4fhXOFZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SxkifzEe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EVb7Uhcc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_u9JOZ4jq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_i8Xhll1G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_GalMsWyF_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_0osk0ODP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_wzM7NXEm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_CdqzhjoW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_GCVUoShn_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_kcI1v22g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_6fB7BVMZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_dgV7q1Eg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_xmK7aJXV_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_SSOX3hqx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_LFmLVSs3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_C0LNXPNG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_EFNf7m83_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_F7ITdjNh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_YFmZEx9h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_FRQVn6o8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xAsDsqfH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_h7GUhQ49_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SzU2P1wa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_N0YdE8Eb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Xou94jYJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_derRYGmp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_AXVCzlbX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_Rs0CtQP2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VOKygGBC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xNXAAor9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_IUa690ZE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MWepctDF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lLj7v8qK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_FYusVm5F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_SWOC5R5h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NTc81FrC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bsmky5zd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Rxv6Ex2z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iqRdL6uz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_D1K8yMsb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_2pmbgLt6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qhbgxsBO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qJCRY9Hm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PKF4tSwT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Q8QdOmHk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ObBnsshS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QveJcD18_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fmUuOjdD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uXm4Wjzm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6zzi6dxv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ioIvo1FM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_W9DYCqak_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_l5NnPEPF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XQ7pouKt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_0Y4ZnXyk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_gHccN9bS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_xd41tbze_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tcGAjip6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hHsQoDlj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_s32cNjAp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sf5TxeLF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wJMRVVED_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BTzlcIiy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vSO7YxFl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_07aZ3xSC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_soQaf0aE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zuVPgocx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uXSqeMtX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_eUooTLAg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UWJJ65CE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_IYCne8LG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RsTwUCow_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RpPcTxZi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UufwWwuD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4C37Jxqt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dPTesVBF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FT3wKDRJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NpmeCTie_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_m3VT5c0K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KMudWsOz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ycl02LuI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Gt0wzCJb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8BL6Z7uk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_0aqqeUGz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_ldXedTk3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ccFpG7vg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qNrIQkTA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vhtdinwm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Cx6Ji2JL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vk7ob8iC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_9V1SFUgG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_J1nAjF7w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iwJistND_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wk9S8vkT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Eai4xSnJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WBNxl0bB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uBYfOf2h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5ioWtita_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0jGxivMa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OW3wh8AH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RgioInnO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_OpffUeFH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_DxXIdD1J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_0WyaBhBa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sEv6Lruu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_eP0zHqGs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_YFtgSocn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_6ZOFUI8v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_cqff1IB7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yP5vzJK3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2PSP8ygP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KEchSdQX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4JtNtUCD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JSrwwUkg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_51Ki0bT8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_V7GionD3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Uia92skq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RLRK1eeh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DZyvqVN0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DiWklaR8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SuN38qVi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_905jefQu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ps54NNXH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JyTUeREY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SctBjSg9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OvvtjMzv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Q72d50yJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JD3RfyJw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sNZFMMrN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_g3btHUD2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Wi5Jc3t3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_J5rRSCab_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_H97MfuJa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_EjnNjEi3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_EMIMTjnS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_llTj9mUE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yJUYWjyd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FZW6ueP1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lR7evhiP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EAOwZT9h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_vgWyUnKH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_q9zWVoyJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rtgRtGYT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RquOJhwB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CLdn85uN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ch1s3K4G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6SnKyNt8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PDJXouIw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hw0VDtov_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TfIlfNrQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rEXdpfxP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XbkMpRgS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vPbNY86p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dPAEMOQS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6agWvasl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_m8AudxGe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_heOPwZRx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yjOJovEK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_TJ5ZW4WT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_omBPw5CU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_dR5B16kh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zpDXF1FN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gJ8XYS5P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_umPaMaq8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_jRbmfVhq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_i4flElBG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0owSTAzm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BOsMN1H0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vt1hhqpm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qKWEvALE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ix6HGrao_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_A0Dnbpkm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qqqcSjmQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qJhAdLgk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_41VL5Yyo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IOX12d79_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_g0lNx2aq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Jt3FmUGf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OLpKwbma_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vYPef9lm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_g6MBSRDf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_quzfbB5q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RIDLAVzg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZLaPYWyF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YjOt4s9U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZY6gIDQn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7a1QweeK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iaTIc6C3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CaeUh7A0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CLy7r0U7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_f3mlegHy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_mezVTrpt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_QevFZ6Ee_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_ZMvUJXBu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_tji7FKux_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dY8TYEJy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EN8CKgBY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Uu3mqARN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SFLuNZUG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AytiXOSh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9HStPx6q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_8LbWcjIV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GArH79sx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7gena98t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SsfIyfmc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VZe160ze_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_txTDRzUZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vfG3B1Lt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nMqphuRI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_A2SvJvdF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aQeEv5s6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7bNrDPTv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_udw4qyMA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_lmIyhjpD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_E3ULjbgs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_l5bvAFjw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_KQI44Wav_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_4NDH9WhX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Q1kIgb6g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_63EgB63m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_DN6xj3M2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_O2np1h8U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_5u6IDSbd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_CkCjF9CE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_1IhmA9Rr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_g9jdBfYs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_GEu8KeGK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_wsjZCEps_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_PhD1oh29_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_KJBz6R2o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ROoLJkoM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_OMQSybL0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_5ew5tgZt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_nyfmk0CN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_rTwu21dT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_gWG9L05L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_DKIUnUw1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ydDAs9Sk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_irnHOs7T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_KWec98DY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_0HRWsFTx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_9RjakxEg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_evo528rf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_m6OW6Xo7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_AgzqzONz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_qPsdW7rX_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_F0pfxQUH;
  SignalLine sLine_4EnoI1AL;
  SignalLine sLine_9ge2iIPH;
  SignalLine sLine_lO62bxDT;
  SignalLine sLine_58g3Fyex;
  SignalBiquad sBiquad_s_AjhaGbo9;
  SignalLine sLine_30vq1ArQ;
  SignalLine sLine_O7QGTsjy;
  SignalLine sLine_jt2yYbaq;
  SignalLine sLine_tNY5afrE;
  SignalBiquad sBiquad_s_yKi9Z4Yb;
  SignalLine sLine_gmK9OJ85;
  SignalLine sLine_mQCh7H4q;
  SignalLine sLine_84qXi3tg;
  SignalLine sLine_hcXInn9f;
  SignalLine sLine_DoswGbd4;
  SignalBiquad sBiquad_s_2mXiAR0Q;
  SignalLine sLine_n21IT7xM;
  SignalLine sLine_VkHrLdWM;
  SignalLine sLine_PoGfAe9o;
  SignalLine sLine_oIApZuDw;
  SignalLine sLine_38rjjq8V;
  SignalBiquad sBiquad_s_1W4ElH8U;
  SignalLine sLine_N33r8JzP;
  SignalLine sLine_S9tdCYTt;
  SignalLine sLine_OU2cm6c0;
  SignalLine sLine_OW6TchOY;
  SignalBiquad sBiquad_s_DfovUTHu;
  SignalLine sLine_I1SA4Qnp;
  SignalLine sLine_Ru5ZnYDn;
  SignalLine sLine_IOK5ADZF;
  SignalLine sLine_XS90AB2o;
  SignalLine sLine_ZtgnT8Ns;
  SignalBiquad sBiquad_s_wb5826pH;
  ControlVar cVar_PWJqKuvd;
  ControlVar cVar_1P2bf5un;
  ControlVar cVar_Jmqtqx4g;
  ControlVar cVar_RppIX3ln;
  ControlSlice cSlice_aCp6KRCU;
  ControlVar cVar_BKPojZDl;
  ControlVar cVar_Uq9Nxydp;
  ControlIf cIf_CdLjdEai;
  ControlIf cIf_IUiJaBar;
  ControlBinop cBinop_qRSFyRCa;
  ControlBinop cBinop_mskdXvY5;
  ControlBinop cBinop_mzZQ44eQ;
  ControlBinop cBinop_IERp80rz;
  ControlBinop cBinop_QLgREsH3;
  ControlIf cIf_YAoxtByJ;
  ControlBinop cBinop_X4yHB9vd;
  ControlBinop cBinop_BVPTYRb0;
  ControlBinop cBinop_ntuQ5vXw;
  ControlBinop cBinop_PkVGKVSp;
  ControlBinop cBinop_6XAgPfQF;
  ControlVar cVar_5gHgH7rf;
  ControlIf cIf_LMmoWdWu;
  ControlIf cIf_f66vy9vk;
  ControlBinop cBinop_pDGSVpSw;
  ControlBinop cBinop_c7y1t7HZ;
  ControlBinop cBinop_1YJEOzi2;
  ControlBinop cBinop_kIr998Nh;
  ControlBinop cBinop_Zs4oovv8;
  ControlIf cIf_pm467h5M;
  ControlBinop cBinop_lxbFWm5Q;
  ControlBinop cBinop_HiGSqDUe;
  ControlBinop cBinop_puOCoAHl;
  ControlBinop cBinop_nDI0kDoG;
  ControlBinop cBinop_1JjqI8pS;
  ControlVar cVar_Hs24rtUk;
  ControlIf cIf_HMiZzIJ6;
  ControlIf cIf_aVk16EWi;
  ControlBinop cBinop_UzahQOIz;
  ControlBinop cBinop_BFo7y5NC;
  ControlBinop cBinop_i0Ka9O4v;
  ControlBinop cBinop_G5l1H9LM;
  ControlBinop cBinop_qGPlTl71;
  ControlIf cIf_VVmbnxtS;
  ControlBinop cBinop_5Mv91S7v;
  ControlBinop cBinop_9n5A6BOw;
  ControlBinop cBinop_c5afwIDh;
  ControlBinop cBinop_bNlYgjT1;
  ControlBinop cBinop_HqchzYvK;
  ControlIf cIf_uPRoKRJD;
  ControlSlice cSlice_zG4kQ4wA;
  ControlVar cVar_9ZJ9yCuO;
  ControlSlice cSlice_fixKJoBa;
  ControlVar cVar_kFBTKeDq;
  ControlSlice cSlice_1ztBVtJ3;
  ControlVar cVar_kGWrsWMl;
  ControlSlice cSlice_urhSFCu6;
  ControlVar cVar_j8IM3GUT;
  ControlBinop cBinop_MbBGleJR;
  ControlBinop cBinop_uiF3Ad0m;
  ControlBinop cBinop_gRtp6cES;
  ControlBinop cBinop_9uwweRxm;
  ControlBinop cBinop_csTLhh41;
  ControlBinop cBinop_lnvf6ogf;
  ControlBinop cBinop_ShYTXadJ;
  ControlBinop cBinop_sz2w5avU;
  ControlVar cVar_FVnVrgNu;
  ControlBinop cBinop_gu8HDPDk;
  ControlBinop cBinop_b6zFpDn0;
  ControlBinop cBinop_gHfSNQxB;
  ControlBinop cBinop_1rzGKKGS;
  ControlBinop cBinop_e77hoSlT;
  ControlBinop cBinop_qInCdKXv;
  ControlBinop cBinop_nqf4vY32;
  ControlBinop cBinop_Z5CX7UHZ;
  ControlVar cVar_y8I1N6EF;
  ControlVar cVar_VGNL7JWA;
  ControlBinop cBinop_9BuJR6Bl;
  ControlBinop cBinop_iFlSXTlc;
  ControlBinop cBinop_NTIEL4ut;
  ControlBinop cBinop_O6Bwiwcl;
  ControlBinop cBinop_P1y8nhsl;
  ControlBinop cBinop_08AJOOgR;
  ControlBinop cBinop_IfShY5IG;
  ControlBinop cBinop_Yg2EVIFE;
  ControlBinop cBinop_XLTPrbd7;
  ControlBinop cBinop_CsvnRpNs;
  ControlBinop cBinop_OqqGIoa4;
  ControlBinop cBinop_X6HC7PEp;
  ControlBinop cBinop_WZwFcVPN;
  ControlBinop cBinop_q1192zkr;
  ControlBinop cBinop_XZYdbgNG;
  ControlBinop cBinop_ijRxh2Qm;
  ControlBinop cBinop_ivKVU9hU;
  ControlBinop cBinop_M2YeMXmy;
  ControlBinop cBinop_ChJoGFEz;
  ControlBinop cBinop_RZfVsQcK;
  ControlVar cVar_sGyn2Bmm;
  ControlVar cVar_JHkNQcJ7;
  ControlVar cVar_pPJVD8dD;
  ControlBinop cBinop_aq31QjE6;
  ControlBinop cBinop_ExjYmQyh;
  ControlBinop cBinop_Ho7xzF5m;
  ControlBinop cBinop_je7cRxeg;
  ControlBinop cBinop_5qp36wL2;
  ControlBinop cBinop_GhuNRszk;
  ControlBinop cBinop_y6vKHAFv;
  ControlBinop cBinop_0NbIofUe;
  ControlBinop cBinop_YSUDesL6;
  ControlBinop cBinop_NflAqDU9;
  ControlBinop cBinop_pvzzk1Jv;
  ControlBinop cBinop_69cqrMAA;
  ControlBinop cBinop_LXiF8V4C;
  ControlBinop cBinop_NqfdLwVI;
  ControlBinop cBinop_ty1zfM8r;
  ControlBinop cBinop_Lqf1BRAU;
  ControlBinop cBinop_Tjkx19Si;
  ControlBinop cBinop_udfCmfes;
  ControlBinop cBinop_kEBAYqJH;
  ControlBinop cBinop_aGDcMyob;
  ControlBinop cBinop_OoGuCtkT;
  ControlBinop cBinop_V87I52Nm;
  ControlBinop cBinop_v7aubxeB;
  ControlVar cVar_K70tnFY0;
  ControlVar cVar_mrmCqZyC;
  ControlVar cVar_GgrixTeC;
  ControlBinop cBinop_uDoaCVmw;
  ControlBinop cBinop_82lF8XfF;
  ControlBinop cBinop_f1C9ddNa;
  ControlBinop cBinop_KCEInLV2;
  ControlBinop cBinop_F0sCoDh0;
  ControlBinop cBinop_r5JwsTzS;
  ControlBinop cBinop_LDMKW4E2;
  ControlBinop cBinop_GhVnCHbz;
  ControlBinop cBinop_3qxFjXV8;
  ControlBinop cBinop_SIRcOFtp;
  ControlBinop cBinop_0bDQmt97;
  ControlBinop cBinop_WfeFWxVz;
  SignalVarf sVarf_tPJPPdvD;
  SignalVarf sVarf_6RSB1SRn;
  SignalVarf sVarf_Cq61F8ZE;
  ControlSlice cSlice_mZBjAowe;
  ControlVar cVar_qBMhzFFC;
  ControlVar cVar_s96Fqr7Y;
  ControlIf cIf_0UtEqoqx;
  ControlIf cIf_N1aKhsEN;
  ControlBinop cBinop_eEGy39ti;
  ControlBinop cBinop_fIgsWAMy;
  ControlBinop cBinop_eFrxa5M3;
  ControlBinop cBinop_tYw1HkZx;
  ControlBinop cBinop_KrNfMpZC;
  ControlIf cIf_saYtiXHE;
  ControlBinop cBinop_R1vXKtgE;
  ControlBinop cBinop_TvZfOHxY;
  ControlBinop cBinop_FQB7WwWv;
  ControlBinop cBinop_ZPCKlTXA;
  ControlBinop cBinop_EGTYLAKn;
  ControlVar cVar_eMjhq3vb;
  ControlIf cIf_QktBtJc3;
  ControlIf cIf_BaOFXrbT;
  ControlBinop cBinop_LwqJV6lh;
  ControlBinop cBinop_xh6UiQsM;
  ControlBinop cBinop_hTjoSmQq;
  ControlBinop cBinop_NfgDeXdx;
  ControlBinop cBinop_sctt6K4F;
  ControlIf cIf_3PN28CfP;
  ControlBinop cBinop_yQf09ajf;
  ControlBinop cBinop_hvvWxsgO;
  ControlBinop cBinop_qxGU4vEG;
  ControlBinop cBinop_cg7iDwdG;
  ControlBinop cBinop_P2WOz98B;
  ControlVar cVar_buzwHiRa;
  ControlIf cIf_m5xDDkXC;
  ControlIf cIf_gBfm3WqP;
  ControlBinop cBinop_ODu4ta5w;
  ControlBinop cBinop_JBlJ2XCw;
  ControlBinop cBinop_ElkHX3bX;
  ControlBinop cBinop_LRRnzXFm;
  ControlBinop cBinop_txvt30av;
  ControlIf cIf_Omf6faGA;
  ControlBinop cBinop_r1yWoVjZ;
  ControlBinop cBinop_ds8AAdIt;
  ControlBinop cBinop_PEZNuajI;
  ControlBinop cBinop_qzcIBqra;
  ControlBinop cBinop_ffXoGqen;
  ControlIf cIf_i8Xhll1G;
  ControlSlice cSlice_0osk0ODP;
  ControlVar cVar_wzM7NXEm;
  ControlSlice cSlice_kcI1v22g;
  ControlVar cVar_6fB7BVMZ;
  ControlSlice cSlice_SSOX3hqx;
  ControlVar cVar_LFmLVSs3;
  ControlSlice cSlice_F7ITdjNh;
  ControlVar cVar_YFmZEx9h;
  ControlBinop cBinop_xNXAAor9;
  ControlBinop cBinop_MWepctDF;
  ControlBinop cBinop_lLj7v8qK;
  ControlBinop cBinop_NTc81FrC;
  ControlBinop cBinop_bsmky5zd;
  ControlBinop cBinop_Rxv6Ex2z;
  ControlBinop cBinop_iqRdL6uz;
  ControlBinop cBinop_D1K8yMsb;
  ControlVar cVar_2pmbgLt6;
  ControlBinop cBinop_qhbgxsBO;
  ControlBinop cBinop_qJCRY9Hm;
  ControlBinop cBinop_PKF4tSwT;
  ControlBinop cBinop_Q8QdOmHk;
  ControlBinop cBinop_ObBnsshS;
  ControlBinop cBinop_QveJcD18;
  ControlBinop cBinop_fmUuOjdD;
  ControlBinop cBinop_6zzi6dxv;
  ControlVar cVar_ioIvo1FM;
  ControlVar cVar_W9DYCqak;
  ControlBinop cBinop_hHsQoDlj;
  ControlBinop cBinop_s32cNjAp;
  ControlBinop cBinop_sf5TxeLF;
  ControlBinop cBinop_BTzlcIiy;
  ControlBinop cBinop_vSO7YxFl;
  ControlBinop cBinop_07aZ3xSC;
  ControlBinop cBinop_soQaf0aE;
  ControlBinop cBinop_zuVPgocx;
  ControlBinop cBinop_uXSqeMtX;
  ControlBinop cBinop_qNrIQkTA;
  ControlBinop cBinop_Cx6Ji2JL;
  ControlBinop cBinop_vk7ob8iC;
  ControlBinop cBinop_iwJistND;
  ControlBinop cBinop_wk9S8vkT;
  ControlBinop cBinop_Eai4xSnJ;
  ControlBinop cBinop_WBNxl0bB;
  ControlBinop cBinop_uBYfOf2h;
  ControlBinop cBinop_5ioWtita;
  ControlBinop cBinop_0jGxivMa;
  ControlBinop cBinop_RgioInnO;
  ControlVar cVar_OpffUeFH;
  ControlVar cVar_DxXIdD1J;
  ControlVar cVar_0WyaBhBa;
  ControlBinop cBinop_2PSP8ygP;
  ControlBinop cBinop_KEchSdQX;
  ControlBinop cBinop_4JtNtUCD;
  ControlBinop cBinop_51Ki0bT8;
  ControlBinop cBinop_V7GionD3;
  ControlBinop cBinop_Uia92skq;
  ControlBinop cBinop_RLRK1eeh;
  ControlBinop cBinop_DZyvqVN0;
  ControlBinop cBinop_yJUYWjyd;
  ControlBinop cBinop_lR7evhiP;
  ControlBinop cBinop_EAOwZT9h;
  ControlBinop cBinop_rtgRtGYT;
  ControlBinop cBinop_RquOJhwB;
  ControlBinop cBinop_CLdn85uN;
  ControlBinop cBinop_ch1s3K4G;
  ControlBinop cBinop_6SnKyNt8;
  ControlBinop cBinop_hw0VDtov;
  ControlBinop cBinop_rEXdpfxP;
  ControlBinop cBinop_XbkMpRgS;
  ControlBinop cBinop_dPAEMOQS;
  ControlBinop cBinop_6agWvasl;
  ControlBinop cBinop_m8AudxGe;
  ControlBinop cBinop_yjOJovEK;
  ControlVar cVar_TJ5ZW4WT;
  ControlVar cVar_omBPw5CU;
  ControlVar cVar_dR5B16kh;
  ControlBinop cBinop_BOsMN1H0;
  ControlBinop cBinop_vt1hhqpm;
  ControlBinop cBinop_qKWEvALE;
  ControlBinop cBinop_A0Dnbpkm;
  ControlBinop cBinop_qqqcSjmQ;
  ControlBinop cBinop_qJhAdLgk;
  ControlBinop cBinop_41VL5Yyo;
  ControlBinop cBinop_IOX12d79;
  ControlBinop cBinop_g0lNx2aq;
  ControlBinop cBinop_iaTIc6C3;
  ControlBinop cBinop_CLy7r0U7;
  ControlBinop cBinop_f3mlegHy;
  SignalVarf sVarf_4N90wOJT;
  SignalVarf sVarf_Zitth5RP;
  SignalVarf sVarf_srCDZ4fI;
  SignalVarf sVarf_noAa11p8;
  SignalVarf sVarf_Z8gCX7Mw;
  SignalVarf sVarf_5jUX3DNo;
  SignalVarf sVarf_XC7Tq37K;
  SignalVarf sVarf_QGotOAlW;
  SignalVarf sVarf_ZNM4X2xO;
  ControlVar cVar_mezVTrpt;
  ControlVar cVar_QevFZ6Ee;
  ControlBinop cBinop_SFLuNZUG;
  ControlBinop cBinop_AytiXOSh;
  ControlBinop cBinop_9HStPx6q;
  ControlBinop cBinop_GArH79sx;
  ControlBinop cBinop_7gena98t;
  ControlBinop cBinop_SsfIyfmc;
  ControlBinop cBinop_VZe160ze;
};

#endif // _HEAVY_CONTEXT_WSTD_EQ_HPP_
