/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_EQ.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_EQ *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_EQ_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_EQ));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_EQ(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_EQ_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_EQ));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_EQ(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_EQ_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_EQ();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_EQ::Heavy_WSTD_EQ(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_F0pfxQUH);
  numBytes += sLine_init(&sLine_4EnoI1AL);
  numBytes += sLine_init(&sLine_9ge2iIPH);
  numBytes += sLine_init(&sLine_lO62bxDT);
  numBytes += sLine_init(&sLine_58g3Fyex);
  numBytes += sBiquad_init(&sBiquad_s_AjhaGbo9);
  numBytes += sLine_init(&sLine_30vq1ArQ);
  numBytes += sLine_init(&sLine_O7QGTsjy);
  numBytes += sLine_init(&sLine_jt2yYbaq);
  numBytes += sLine_init(&sLine_tNY5afrE);
  numBytes += sBiquad_init(&sBiquad_s_yKi9Z4Yb);
  numBytes += sLine_init(&sLine_gmK9OJ85);
  numBytes += sLine_init(&sLine_mQCh7H4q);
  numBytes += sLine_init(&sLine_84qXi3tg);
  numBytes += sLine_init(&sLine_hcXInn9f);
  numBytes += sLine_init(&sLine_DoswGbd4);
  numBytes += sBiquad_init(&sBiquad_s_2mXiAR0Q);
  numBytes += sLine_init(&sLine_n21IT7xM);
  numBytes += sLine_init(&sLine_VkHrLdWM);
  numBytes += sLine_init(&sLine_PoGfAe9o);
  numBytes += sLine_init(&sLine_oIApZuDw);
  numBytes += sLine_init(&sLine_38rjjq8V);
  numBytes += sBiquad_init(&sBiquad_s_1W4ElH8U);
  numBytes += sLine_init(&sLine_N33r8JzP);
  numBytes += sLine_init(&sLine_S9tdCYTt);
  numBytes += sLine_init(&sLine_OU2cm6c0);
  numBytes += sLine_init(&sLine_OW6TchOY);
  numBytes += sBiquad_init(&sBiquad_s_DfovUTHu);
  numBytes += sLine_init(&sLine_I1SA4Qnp);
  numBytes += sLine_init(&sLine_Ru5ZnYDn);
  numBytes += sLine_init(&sLine_IOK5ADZF);
  numBytes += sLine_init(&sLine_XS90AB2o);
  numBytes += sLine_init(&sLine_ZtgnT8Ns);
  numBytes += sBiquad_init(&sBiquad_s_wb5826pH);
  numBytes += cVar_init_f(&cVar_PWJqKuvd, 0.0f);
  numBytes += cVar_init_f(&cVar_1P2bf5un, 0.0f);
  numBytes += cVar_init_f(&cVar_Jmqtqx4g, 0.0f);
  numBytes += cVar_init_f(&cVar_RppIX3ln, 0.0f);
  numBytes += cSlice_init(&cSlice_aCp6KRCU, 1, -1);
  numBytes += cVar_init_f(&cVar_BKPojZDl, 1337.0f);
  numBytes += cVar_init_f(&cVar_Uq9Nxydp, 0.0f);
  numBytes += cIf_init(&cIf_CdLjdEai, false);
  numBytes += cIf_init(&cIf_IUiJaBar, false);
  numBytes += cBinop_init(&cBinop_qRSFyRCa, 0.0f); // __pow
  numBytes += cIf_init(&cIf_YAoxtByJ, false);
  numBytes += cBinop_init(&cBinop_ntuQ5vXw, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_PkVGKVSp, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_6XAgPfQF, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_5gHgH7rf, 0.0f);
  numBytes += cIf_init(&cIf_LMmoWdWu, false);
  numBytes += cIf_init(&cIf_f66vy9vk, false);
  numBytes += cBinop_init(&cBinop_pDGSVpSw, 0.0f); // __pow
  numBytes += cIf_init(&cIf_pm467h5M, false);
  numBytes += cBinop_init(&cBinop_puOCoAHl, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_nDI0kDoG, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_1JjqI8pS, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_Hs24rtUk, 0.0f);
  numBytes += cIf_init(&cIf_HMiZzIJ6, false);
  numBytes += cIf_init(&cIf_aVk16EWi, false);
  numBytes += cBinop_init(&cBinop_UzahQOIz, 0.0f); // __pow
  numBytes += cIf_init(&cIf_VVmbnxtS, false);
  numBytes += cBinop_init(&cBinop_c5afwIDh, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_bNlYgjT1, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_HqchzYvK, -15.0f); // __eq
  numBytes += cIf_init(&cIf_uPRoKRJD, false);
  numBytes += cSlice_init(&cSlice_zG4kQ4wA, 1, -1);
  numBytes += cVar_init_f(&cVar_9ZJ9yCuO, 0.0f);
  numBytes += cSlice_init(&cSlice_fixKJoBa, 1, -1);
  numBytes += cVar_init_f(&cVar_kFBTKeDq, 0.0f);
  numBytes += cSlice_init(&cSlice_1ztBVtJ3, 1, -1);
  numBytes += cVar_init_f(&cVar_kGWrsWMl, 0.0f);
  numBytes += cSlice_init(&cSlice_urhSFCu6, 1, -1);
  numBytes += cVar_init_f(&cVar_j8IM3GUT, 0.313f);
  numBytes += cBinop_init(&cBinop_uiF3Ad0m, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_gRtp6cES, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_FVnVrgNu, 0.0f);
  numBytes += cVar_init_f(&cVar_y8I1N6EF, 1337.0f);
  numBytes += cVar_init_f(&cVar_VGNL7JWA, 0.3f);
  numBytes += cBinop_init(&cBinop_iFlSXTlc, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_P1y8nhsl, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_08AJOOgR, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_IfShY5IG, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Yg2EVIFE, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_XLTPrbd7, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_OqqGIoa4, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_X6HC7PEp, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_sGyn2Bmm, 0.0f);
  numBytes += cVar_init_f(&cVar_JHkNQcJ7, 1337.0f);
  numBytes += cVar_init_f(&cVar_pPJVD8dD, 0.313f);
  numBytes += cBinop_init(&cBinop_ExjYmQyh, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_5qp36wL2, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_GhuNRszk, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_y6vKHAFv, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_0NbIofUe, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_NflAqDU9, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_pvzzk1Jv, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_K70tnFY0, 0.0f);
  numBytes += cVar_init_f(&cVar_mrmCqZyC, 1037.0f);
  numBytes += cVar_init_f(&cVar_GgrixTeC, 0.4f);
  numBytes += cBinop_init(&cBinop_82lF8XfF, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_F0sCoDh0, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_r5JwsTzS, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_LDMKW4E2, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_GhVnCHbz, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_3qxFjXV8, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_tPJPPdvD, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_6RSB1SRn, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Cq61F8ZE, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_mZBjAowe, 1, -1);
  numBytes += cVar_init_f(&cVar_qBMhzFFC, 1337.0f);
  numBytes += cVar_init_f(&cVar_s96Fqr7Y, 0.0f);
  numBytes += cIf_init(&cIf_0UtEqoqx, false);
  numBytes += cIf_init(&cIf_N1aKhsEN, false);
  numBytes += cBinop_init(&cBinop_eEGy39ti, 0.0f); // __pow
  numBytes += cIf_init(&cIf_saYtiXHE, false);
  numBytes += cBinop_init(&cBinop_FQB7WwWv, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_ZPCKlTXA, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_EGTYLAKn, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_eMjhq3vb, 0.0f);
  numBytes += cIf_init(&cIf_QktBtJc3, false);
  numBytes += cIf_init(&cIf_BaOFXrbT, false);
  numBytes += cBinop_init(&cBinop_LwqJV6lh, 0.0f); // __pow
  numBytes += cIf_init(&cIf_3PN28CfP, false);
  numBytes += cBinop_init(&cBinop_qxGU4vEG, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_cg7iDwdG, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_P2WOz98B, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_buzwHiRa, 0.0f);
  numBytes += cIf_init(&cIf_m5xDDkXC, false);
  numBytes += cIf_init(&cIf_gBfm3WqP, false);
  numBytes += cBinop_init(&cBinop_ODu4ta5w, 0.0f); // __pow
  numBytes += cIf_init(&cIf_Omf6faGA, false);
  numBytes += cBinop_init(&cBinop_PEZNuajI, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_qzcIBqra, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_ffXoGqen, -15.0f); // __eq
  numBytes += cIf_init(&cIf_i8Xhll1G, false);
  numBytes += cSlice_init(&cSlice_0osk0ODP, 1, -1);
  numBytes += cVar_init_f(&cVar_wzM7NXEm, 0.0f);
  numBytes += cSlice_init(&cSlice_kcI1v22g, 1, -1);
  numBytes += cVar_init_f(&cVar_6fB7BVMZ, 0.0f);
  numBytes += cSlice_init(&cSlice_SSOX3hqx, 1, -1);
  numBytes += cVar_init_f(&cVar_LFmLVSs3, 0.0f);
  numBytes += cSlice_init(&cSlice_F7ITdjNh, 1, -1);
  numBytes += cVar_init_f(&cVar_YFmZEx9h, 0.313f);
  numBytes += cBinop_init(&cBinop_MWepctDF, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_lLj7v8qK, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_2pmbgLt6, 0.0f);
  numBytes += cVar_init_f(&cVar_ioIvo1FM, 1337.0f);
  numBytes += cVar_init_f(&cVar_W9DYCqak, 0.3f);
  numBytes += cBinop_init(&cBinop_s32cNjAp, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_vSO7YxFl, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_07aZ3xSC, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_soQaf0aE, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_zuVPgocx, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_uXSqeMtX, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Cx6Ji2JL, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_vk7ob8iC, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_OpffUeFH, 0.0f);
  numBytes += cVar_init_f(&cVar_DxXIdD1J, 1337.0f);
  numBytes += cVar_init_f(&cVar_0WyaBhBa, 0.313f);
  numBytes += cBinop_init(&cBinop_KEchSdQX, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_V7GionD3, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Uia92skq, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_RLRK1eeh, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_DZyvqVN0, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_lR7evhiP, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_EAOwZT9h, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_TJ5ZW4WT, 0.0f);
  numBytes += cVar_init_f(&cVar_omBPw5CU, 1037.0f);
  numBytes += cVar_init_f(&cVar_dR5B16kh, 0.4f);
  numBytes += cBinop_init(&cBinop_vt1hhqpm, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_qqqcSjmQ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_qJhAdLgk, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_41VL5Yyo, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_IOX12d79, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_g0lNx2aq, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_4N90wOJT, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Zitth5RP, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_srCDZ4fI, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_noAa11p8, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Z8gCX7Mw, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_5jUX3DNo, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_XC7Tq37K, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_QGotOAlW, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ZNM4X2xO, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_mezVTrpt, 5705.6f);
  numBytes += cVar_init_f(&cVar_QevFZ6Ee, 313.3f);
  numBytes += cBinop_init(&cBinop_SFLuNZUG, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_AytiXOSh, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_9HStPx6q, 0.0f); // __div
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_EQ::~Heavy_WSTD_EQ() {
  // nothing to free
}

HvTable *Heavy_WSTD_EQ::getTableForHash(hv_uint32_t tableHash) {
  return nullptr;
}

void Heavy_WSTD_EQ::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_lmIyhjpD_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_l5bvAFjw_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_E3ULjbgs_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qPsdW7rX_sendMessage);
      break;
    }
    case 0x24295C10: { // 1010-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Q1kIgb6g_sendMessage);
      break;
    }
    case 0x3649681E: { // 1010-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_63EgB63m_sendMessage);
      break;
    }
    case 0xD5A8E74D: { // 1010-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_KQI44Wav_sendMessage);
      break;
    }
    case 0x60D6F65: { // 1010-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4NDH9WhX_sendMessage);
      break;
    }
    case 0x37E92263: { // 1010-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DN6xj3M2_sendMessage);
      break;
    }
    case 0x2271964: { // 1069-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1IhmA9Rr_sendMessage);
      break;
    }
    case 0xA61C5543: { // 1069-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_CkCjF9CE_sendMessage);
      break;
    }
    case 0x1E13C49D: { // 1069-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5u6IDSbd_sendMessage);
      break;
    }
    case 0xE7448D12: { // 1110-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wsjZCEps_sendMessage);
      break;
    }
    case 0x5F31ED81: { // 1110-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GEu8KeGK_sendMessage);
      break;
    }
    case 0xC3520438: { // 1110-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_g9jdBfYs_sendMessage);
      break;
    }
    case 0xB2DA8F9A: { // 1151-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ROoLJkoM_sendMessage);
      break;
    }
    case 0x668DC2C1: { // 1151-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_KJBz6R2o_sendMessage);
      break;
    }
    case 0x413B9F30: { // 1151-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_PhD1oh29_sendMessage);
      break;
    }
    case 0x845815A0: { // 1163-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_nyfmk0CN_sendMessage);
      break;
    }
    case 0x5CD8AF91: { // 1163-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_rTwu21dT_sendMessage);
      break;
    }
    case 0x188BB7A0: { // 1163-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_OMQSybL0_sendMessage);
      break;
    }
    case 0xE3BB13E4: { // 1163-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5ew5tgZt_sendMessage);
      break;
    }
    case 0x3693B415: { // 1163-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gWG9L05L_sendMessage);
      break;
    }
    case 0x1A14721E: { // 1222-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_irnHOs7T_sendMessage);
      break;
    }
    case 0x446DC164: { // 1222-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ydDAs9Sk_sendMessage);
      break;
    }
    case 0x32F45A8B: { // 1222-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DKIUnUw1_sendMessage);
      break;
    }
    case 0x1286072C: { // 1263-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9RjakxEg_sendMessage);
      break;
    }
    case 0x7902A17C: { // 1263-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0HRWsFTx_sendMessage);
      break;
    }
    case 0x7A57C19C: { // 1263-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_KWec98DY_sendMessage);
      break;
    }
    case 0x170C9887: { // 1304-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_AgzqzONz_sendMessage);
      break;
    }
    case 0xED0CBA1C: { // 1304-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_m6OW6Xo7_sendMessage);
      break;
    }
    case 0xDA3A818C: { // 1304-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_evo528rf_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_O2np1h8U_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_EQ::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 2: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 3: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 4;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_EQ::cVar_PWJqKuvd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_txTDRzUZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_1P2bf5un_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vfG3B1Lt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_Jmqtqx4g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nMqphuRI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_RppIX3ln_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_A2SvJvdF_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dY8TYEJy_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EN8CKgBY_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Uu3mqARN_sendMessage);
}

void Heavy_WSTD_EQ::cSwitchcase_hvKdBgPi_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_aCp6KRCU, 0, m, &cSlice_aCp6KRCU_sendMessage);
      break;
    }
    default: {
      cSwitchcase_jerBwwDl_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_aCp6KRCU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_eYh4AZzE_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_eYh4AZzE_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_BKPojZDl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_eYh4AZzE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_eYh4AZzE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_KQI44Wav_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_Uq9Nxydp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_X4yHB9vd_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_CdLjdEai, 0, m, &cIf_CdLjdEai_sendMessage);
}

void Heavy_WSTD_EQ::cIf_CdLjdEai_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_BVPTYRb0_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_IUiJaBar_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_oZh9tmvy_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_IERp80rz_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_ZrWicJDo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_qRSFyRCa, HV_BINOP_POW, 0, m, &cBinop_qRSFyRCa_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_qRSFyRCa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YAoxtByJ, 0, m, &cIf_YAoxtByJ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_mskdXvY5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_QLgREsH3_sendMessage);
}

void Heavy_WSTD_EQ::cCast_smuCxYay_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_mzZQ44eQ_sendMessage);
}

void Heavy_WSTD_EQ::cCast_7RGVrHkC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IUiJaBar, 0, m, &cIf_IUiJaBar_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_mzZQ44eQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IUiJaBar, 1, m, &cIf_IUiJaBar_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_IERp80rz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_mskdXvY5_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_oZh9tmvy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_YAoxtByJ, 0, m, &cIf_YAoxtByJ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_QLgREsH3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qRSFyRCa, HV_BINOP_POW, 1, m, &cBinop_qRSFyRCa_sendMessage);
  cMsg_ZrWicJDo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_YAoxtByJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_tPJPPdvD, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_X4yHB9vd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CdLjdEai, 1, m, &cIf_CdLjdEai_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_BVPTYRb0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PkVGKVSp, HV_BINOP_GREATER_THAN, 1, m, &cBinop_PkVGKVSp_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_6XAgPfQF, HV_BINOP_EQ, 1, m, &cBinop_6XAgPfQF_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_MQNZPY9t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ntuQ5vXw, HV_BINOP_ADD, 0, m, &cBinop_ntuQ5vXw_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ntuQ5vXw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_smuCxYay_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7RGVrHkC_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_PkVGKVSp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YAoxtByJ, 1, m, &cIf_YAoxtByJ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_6XAgPfQF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_E2C6Vn1V_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_E2C6Vn1V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_tPJPPdvD, m);
}

void Heavy_WSTD_EQ::cCast_29bHStIy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ntuQ5vXw, HV_BINOP_ADD, 1, m, &cBinop_ntuQ5vXw_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_PkVGKVSp, HV_BINOP_GREATER_THAN, 0, m, &cBinop_PkVGKVSp_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_6XAgPfQF, HV_BINOP_EQ, 0, m, &cBinop_6XAgPfQF_sendMessage);
}

void Heavy_WSTD_EQ::cCast_GsBBdmJO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MQNZPY9t_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_BPi11I13_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Uq9Nxydp, 0, m, &cVar_Uq9Nxydp_sendMessage);
}

void Heavy_WSTD_EQ::cVar_5gHgH7rf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_lxbFWm5Q_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_LMmoWdWu, 0, m, &cIf_LMmoWdWu_sendMessage);
}

void Heavy_WSTD_EQ::cIf_LMmoWdWu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_HiGSqDUe_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_f66vy9vk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_K5FmRsO8_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_kIr998Nh_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_tJ7IjlqA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_pDGSVpSw, HV_BINOP_POW, 0, m, &cBinop_pDGSVpSw_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_pDGSVpSw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pm467h5M, 0, m, &cIf_pm467h5M_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_c7y1t7HZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_Zs4oovv8_sendMessage);
}

void Heavy_WSTD_EQ::cCast_I7a4W1p5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_1YJEOzi2_sendMessage);
}

void Heavy_WSTD_EQ::cCast_PWOzEYkR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_f66vy9vk, 0, m, &cIf_f66vy9vk_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_1YJEOzi2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_f66vy9vk, 1, m, &cIf_f66vy9vk_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_kIr998Nh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_c7y1t7HZ_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_K5FmRsO8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_pm467h5M, 0, m, &cIf_pm467h5M_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Zs4oovv8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pDGSVpSw, HV_BINOP_POW, 1, m, &cBinop_pDGSVpSw_sendMessage);
  cMsg_tJ7IjlqA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_pm467h5M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_SIRcOFtp_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_0bDQmt97_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_WfeFWxVz_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_lxbFWm5Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LMmoWdWu, 1, m, &cIf_LMmoWdWu_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_HiGSqDUe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nDI0kDoG, HV_BINOP_GREATER_THAN, 1, m, &cBinop_nDI0kDoG_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_1JjqI8pS, HV_BINOP_EQ, 1, m, &cBinop_1JjqI8pS_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_CfjRG7OZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_puOCoAHl, HV_BINOP_ADD, 0, m, &cBinop_puOCoAHl_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_puOCoAHl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_I7a4W1p5_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PWOzEYkR_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_nDI0kDoG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pm467h5M, 1, m, &cIf_pm467h5M_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_1JjqI8pS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ABDcoKFa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_ABDcoKFa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_SIRcOFtp_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_0bDQmt97_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_WfeFWxVz_sendMessage);
}

void Heavy_WSTD_EQ::cCast_UxQeHFcg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5gHgH7rf, 0, m, &cVar_5gHgH7rf_sendMessage);
}

void Heavy_WSTD_EQ::cCast_UZ1kiLqE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_puOCoAHl, HV_BINOP_ADD, 1, m, &cBinop_puOCoAHl_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_nDI0kDoG, HV_BINOP_GREATER_THAN, 0, m, &cBinop_nDI0kDoG_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_1JjqI8pS, HV_BINOP_EQ, 0, m, &cBinop_1JjqI8pS_sendMessage);
}

void Heavy_WSTD_EQ::cCast_kdtbrG6R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CfjRG7OZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_Hs24rtUk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_5Mv91S7v_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_HMiZzIJ6, 0, m, &cIf_HMiZzIJ6_sendMessage);
}

void Heavy_WSTD_EQ::cIf_HMiZzIJ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_9n5A6BOw_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_aVk16EWi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_tVvxCTXw_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_G5l1H9LM_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_eSQ1MWhQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_UzahQOIz, HV_BINOP_POW, 0, m, &cBinop_UzahQOIz_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_UzahQOIz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VVmbnxtS, 0, m, &cIf_VVmbnxtS_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_BFo7y5NC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_qGPlTl71_sendMessage);
}

void Heavy_WSTD_EQ::cCast_QDGnMJCj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aVk16EWi, 0, m, &cIf_aVk16EWi_sendMessage);
}

void Heavy_WSTD_EQ::cCast_gXQ7pUYV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_i0Ka9O4v_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_i0Ka9O4v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aVk16EWi, 1, m, &cIf_aVk16EWi_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_G5l1H9LM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_BFo7y5NC_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_tVvxCTXw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_VVmbnxtS, 0, m, &cIf_VVmbnxtS_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_qGPlTl71_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UzahQOIz, HV_BINOP_POW, 1, m, &cBinop_UzahQOIz_sendMessage);
  cMsg_eSQ1MWhQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_VVmbnxtS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_Cq61F8ZE, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_5Mv91S7v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HMiZzIJ6, 1, m, &cIf_HMiZzIJ6_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_9n5A6BOw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bNlYgjT1, HV_BINOP_GREATER_THAN, 1, m, &cBinop_bNlYgjT1_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_HqchzYvK, HV_BINOP_EQ, 1, m, &cBinop_HqchzYvK_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_fhYQEV2Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_c5afwIDh, HV_BINOP_ADD, 0, m, &cBinop_c5afwIDh_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_c5afwIDh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gXQ7pUYV_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QDGnMJCj_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_bNlYgjT1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VVmbnxtS, 1, m, &cIf_VVmbnxtS_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_HqchzYvK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dqBUQKm8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_dqBUQKm8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Cq61F8ZE, m);
}

void Heavy_WSTD_EQ::cCast_xpyccycD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fhYQEV2Z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_nFnpfDVf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_c5afwIDh, HV_BINOP_ADD, 1, m, &cBinop_c5afwIDh_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_bNlYgjT1, HV_BINOP_GREATER_THAN, 0, m, &cBinop_bNlYgjT1_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_HqchzYvK, HV_BINOP_EQ, 0, m, &cBinop_HqchzYvK_sendMessage);
}

void Heavy_WSTD_EQ::cCast_lxmy60Bu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Hs24rtUk, 0, m, &cVar_Hs24rtUk_sendMessage);
}

void Heavy_WSTD_EQ::cIf_uPRoKRJD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_6RSB1SRn, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cSwitchcase_miXh3fzr_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_zG4kQ4wA, 0, m, &cSlice_zG4kQ4wA_sendMessage);
      break;
    }
    default: {
      cSwitchcase_nTfFK86M_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_zG4kQ4wA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_93l9BUbM_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_93l9BUbM_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_9ZJ9yCuO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_93l9BUbM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_93l9BUbM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Q1kIgb6g_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_nTfFK86M_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_fixKJoBa, 0, m, &cSlice_fixKJoBa_sendMessage);
      break;
    }
    default: {
      cSwitchcase_hvKdBgPi_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_fixKJoBa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_qB3BZiWv_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_qB3BZiWv_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_kFBTKeDq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_qB3BZiWv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_qB3BZiWv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_DN6xj3M2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_jerBwwDl_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_1ztBVtJ3, 0, m, &cSlice_1ztBVtJ3_sendMessage);
      break;
    }
    default: {
      cSwitchcase_bUIICF0U_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_1ztBVtJ3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_MVmHiNH0_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_MVmHiNH0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_kGWrsWMl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_MVmHiNH0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_MVmHiNH0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_63EgB63m_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_bUIICF0U_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_urhSFCu6, 0, m, &cSlice_urhSFCu6_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_urhSFCu6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_DZUuMThg_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_DZUuMThg_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_j8IM3GUT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_DZUuMThg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_DZUuMThg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_4NDH9WhX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_fvOnQk0B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_F0pfxQUH, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_Vayi6Xrb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4EnoI1AL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_8IyLDjKz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9ge2iIPH, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_eLkfIfbQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lO62bxDT, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_ESvws7Br_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_58g3Fyex, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_koBq9WKi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_RLwayXtK_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_RLwayXtK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uiF3Ad0m, HV_BINOP_DIVIDE, 1, m, &cBinop_uiF3Ad0m_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Q6u6bCJB_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_nkBYAUU0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_MbBGleJR_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_PBlAlABe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_nkBYAUU0_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_MbBGleJR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uiF3Ad0m, HV_BINOP_DIVIDE, 0, m, &cBinop_uiF3Ad0m_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Q6u6bCJB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PBlAlABe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_uiF3Ad0m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gRtp6cES, HV_BINOP_MULTIPLY, 1, m, &cBinop_gRtp6cES_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_gRtp6cES_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JjIGIKIs_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PTGckmZw_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_qkbBtE8A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_B9yKh2MQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_Nk7nhqIo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_C5PiJnuT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_9uwweRxm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_csTLhh41_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_csTLhh41_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gRtp6cES, HV_BINOP_MULTIPLY, 0, m, &cBinop_gRtp6cES_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_lnvf6ogf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_ShYTXadJ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ShYTXadJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xrZ3bSnk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_sz2w5avU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FVnVrgNu, 1, m, &cVar_FVnVrgNu_sendMessage);
}

void Heavy_WSTD_EQ::cVar_FVnVrgNu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hpMUqsGa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_gu8HDPDk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_P1y8nhsl, HV_BINOP_MULTIPLY, 1, m, &cBinop_P1y8nhsl_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_b6zFpDn0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_gu8HDPDk_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_gHfSNQxB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_1rzGKKGS_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_1rzGKKGS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_08AJOOgR, HV_BINOP_MULTIPLY, 1, m, &cBinop_08AJOOgR_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_e77hoSlT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IfShY5IG, HV_BINOP_MULTIPLY, 1, m, &cBinop_IfShY5IG_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_qInCdKXv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_e77hoSlT_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_nqf4vY32_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Yg2EVIFE, HV_BINOP_MULTIPLY, 1, m, &cBinop_Yg2EVIFE_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_9N4O6wZO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Z5CX7UHZ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Z5CX7UHZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XLTPrbd7, HV_BINOP_MULTIPLY, 1, m, &cBinop_XLTPrbd7_sendMessage);
}

void Heavy_WSTD_EQ::cVar_y8I1N6EF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BYeu5h76_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_9uwweRxm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ympJpjrf_sendMessage);
}

void Heavy_WSTD_EQ::cVar_VGNL7JWA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_lnvf6ogf_sendMessage);
}

void Heavy_WSTD_EQ::cCast_JjIGIKIs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_qkbBtE8A_sendMessage);
}

void Heavy_WSTD_EQ::cCast_PTGckmZw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_Nk7nhqIo_sendMessage);
}

void Heavy_WSTD_EQ::cSend_B9yKh2MQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_5u6IDSbd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_C5PiJnuT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_CkCjF9CE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_B3kCx9w3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_1IhmA9Rr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_xrZ3bSnk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_9BuJR6Bl_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_9BuJR6Bl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iFlSXTlc, HV_BINOP_MULTIPLY, 1, m, &cBinop_iFlSXTlc_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_iFlSXTlc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_NTIEL4ut_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_NTIEL4ut_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_B3kCx9w3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_hpMUqsGa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_O6Bwiwcl_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_O6Bwiwcl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZiQwMp9R_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XQfPUM99_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HgDKLgZG_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Py242o26_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vg15mao9_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EoRbkOpZ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_P1y8nhsl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fvOnQk0B_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_08AJOOgR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Vayi6Xrb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_IfShY5IG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8IyLDjKz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_Yg2EVIFE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eLkfIfbQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_XLTPrbd7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ESvws7Br_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_ZGhQjOIZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VGNL7JWA, 1, m, &cVar_VGNL7JWA_sendMessage);
}

void Heavy_WSTD_EQ::cCast_3qYys916_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_y8I1N6EF, 0, m, &cVar_y8I1N6EF_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Py242o26_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IfShY5IG, HV_BINOP_MULTIPLY, 0, m, &cBinop_IfShY5IG_sendMessage);
}

void Heavy_WSTD_EQ::cCast_ZiQwMp9R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_EoRbkOpZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_P1y8nhsl, HV_BINOP_MULTIPLY, 0, m, &cBinop_P1y8nhsl_sendMessage);
}

void Heavy_WSTD_EQ::cCast_HgDKLgZG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Yg2EVIFE, HV_BINOP_MULTIPLY, 0, m, &cBinop_Yg2EVIFE_sendMessage);
}

void Heavy_WSTD_EQ::cCast_XQfPUM99_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XLTPrbd7, HV_BINOP_MULTIPLY, 0, m, &cBinop_XLTPrbd7_sendMessage);
}

void Heavy_WSTD_EQ::cCast_vg15mao9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_08AJOOgR, HV_BINOP_MULTIPLY, 0, m, &cBinop_08AJOOgR_sendMessage);
}

void Heavy_WSTD_EQ::cCast_BYeu5h76_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VGNL7JWA, 0, m, &cVar_VGNL7JWA_sendMessage);
}

void Heavy_WSTD_EQ::cCast_ympJpjrf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FVnVrgNu, 0, m, &cVar_FVnVrgNu_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_SkngodKH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_30vq1ArQ, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_Dml4hLbo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_O7QGTsjy, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_4hOYCczX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jt2yYbaq, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_7iYsiTDz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tNY5afrE, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_v9WuaQq3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_IVwIsh12_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_IVwIsh12_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OqqGIoa4, HV_BINOP_DIVIDE, 1, m, &cBinop_OqqGIoa4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8ewlGY91_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_ziRL9k5U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_CsvnRpNs_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_XDnakHGJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_ziRL9k5U_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_CsvnRpNs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OqqGIoa4, HV_BINOP_DIVIDE, 0, m, &cBinop_OqqGIoa4_sendMessage);
}

void Heavy_WSTD_EQ::cCast_8ewlGY91_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XDnakHGJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_OqqGIoa4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_X6HC7PEp, HV_BINOP_MULTIPLY, 1, m, &cBinop_X6HC7PEp_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_X6HC7PEp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LnXBgtSI_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_b79EWyj5_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_KnxrdPUg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ldRYAxNc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_8g94BvNV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_HL7OUOBs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_WZwFcVPN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_q1192zkr_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_q1192zkr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_X6HC7PEp, HV_BINOP_MULTIPLY, 0, m, &cBinop_X6HC7PEp_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_XZYdbgNG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_ijRxh2Qm_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ijRxh2Qm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PDXQf1zt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_ivKVU9hU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GhuNRszk, HV_BINOP_MULTIPLY, 1, m, &cBinop_GhuNRszk_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_M2YeMXmy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sGyn2Bmm, 1, m, &cVar_sGyn2Bmm_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ChJoGFEz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_y6vKHAFv, HV_BINOP_MULTIPLY, 1, m, &cBinop_y6vKHAFv_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_fK4DeXBp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_RZfVsQcK_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_RZfVsQcK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0NbIofUe, HV_BINOP_MULTIPLY, 1, m, &cBinop_0NbIofUe_sendMessage);
}

void Heavy_WSTD_EQ::cVar_sGyn2Bmm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XrRldhdJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_JHkNQcJ7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CdF2t0u5_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_WZwFcVPN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_s7dsob64_sendMessage);
}

void Heavy_WSTD_EQ::cVar_pPJVD8dD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_XZYdbgNG_sendMessage);
}

void Heavy_WSTD_EQ::cCast_b79EWyj5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_8g94BvNV_sendMessage);
}

void Heavy_WSTD_EQ::cCast_LnXBgtSI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_KnxrdPUg_sendMessage);
}

void Heavy_WSTD_EQ::cSend_ldRYAxNc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_g9jdBfYs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_HL7OUOBs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_GEu8KeGK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_BISDXd6P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_wsjZCEps_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_PDXQf1zt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_aq31QjE6_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_aq31QjE6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ExjYmQyh, HV_BINOP_MULTIPLY, 1, m, &cBinop_ExjYmQyh_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ExjYmQyh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Ho7xzF5m_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Ho7xzF5m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_BISDXd6P_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_XrRldhdJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_je7cRxeg_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_je7cRxeg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qohWaemW_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FMPKPs6P_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_l2FjmrwZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qQivOeoV_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_5qp36wL2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SkngodKH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_GhuNRszk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Dml4hLbo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_y6vKHAFv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4hOYCczX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_0NbIofUe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7iYsiTDz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_VTYzPGdA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JHkNQcJ7, 0, m, &cVar_JHkNQcJ7_sendMessage);
}

void Heavy_WSTD_EQ::cCast_C223am0Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pPJVD8dD, 1, m, &cVar_pPJVD8dD_sendMessage);
}

void Heavy_WSTD_EQ::cCast_CdF2t0u5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pPJVD8dD, 0, m, &cVar_pPJVD8dD_sendMessage);
}

void Heavy_WSTD_EQ::cCast_s7dsob64_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sGyn2Bmm, 0, m, &cVar_sGyn2Bmm_sendMessage);
}

void Heavy_WSTD_EQ::cCast_FMPKPs6P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_y6vKHAFv, HV_BINOP_MULTIPLY, 0, m, &cBinop_y6vKHAFv_sendMessage);
}

void Heavy_WSTD_EQ::cCast_qohWaemW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0NbIofUe, HV_BINOP_MULTIPLY, 0, m, &cBinop_0NbIofUe_sendMessage);
}

void Heavy_WSTD_EQ::cCast_qQivOeoV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5qp36wL2, HV_BINOP_MULTIPLY, 0, m, &cBinop_5qp36wL2_sendMessage);
}

void Heavy_WSTD_EQ::cCast_l2FjmrwZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GhuNRszk, HV_BINOP_MULTIPLY, 0, m, &cBinop_GhuNRszk_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_3kZyhQhS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gmK9OJ85, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_WlnyT9XA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mQCh7H4q, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_YNpGQPQu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_84qXi3tg, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_g14Ssnn2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hcXInn9f, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_fY1NJHgc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DoswGbd4, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_Hik5Os4x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Y3VqARlF_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_Y3VqARlF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NflAqDU9, HV_BINOP_DIVIDE, 1, m, &cBinop_NflAqDU9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tG22Rc50_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_hhFIkFby_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_YSUDesL6_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_ckCCNf7J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_hhFIkFby_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_YSUDesL6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NflAqDU9, HV_BINOP_DIVIDE, 0, m, &cBinop_NflAqDU9_sendMessage);
}

void Heavy_WSTD_EQ::cCast_tG22Rc50_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ckCCNf7J_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_NflAqDU9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pvzzk1Jv, HV_BINOP_MULTIPLY, 1, m, &cBinop_pvzzk1Jv_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_pvzzk1Jv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Om2Zq2Ql_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jmTzalDt_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_r0ANmhyM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_qJf8gLKh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_lA8Eubzx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_qD1340gg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_69cqrMAA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_LXiF8V4C_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_LXiF8V4C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pvzzk1Jv, HV_BINOP_MULTIPLY, 0, m, &cBinop_pvzzk1Jv_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_NqfdLwVI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_ty1zfM8r_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ty1zfM8r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_p6u9OYmq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_Lqf1BRAU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_F0sCoDh0, HV_BINOP_MULTIPLY, 1, m, &cBinop_F0sCoDh0_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_y9vHIOBi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Tjkx19Si_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Tjkx19Si_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Lqf1BRAU_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_5gIlEmJN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_udfCmfes_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_udfCmfes_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_r5JwsTzS, HV_BINOP_MULTIPLY, 1, m, &cBinop_r5JwsTzS_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_kEBAYqJH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LDMKW4E2, HV_BINOP_MULTIPLY, 1, m, &cBinop_LDMKW4E2_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_JoduXMLD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_aGDcMyob_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_aGDcMyob_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_kEBAYqJH_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_OoGuCtkT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_K70tnFY0, 1, m, &cVar_K70tnFY0_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_V87I52Nm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GhVnCHbz, HV_BINOP_MULTIPLY, 1, m, &cBinop_GhVnCHbz_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_mFigPqak_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_v7aubxeB_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_v7aubxeB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3qxFjXV8, HV_BINOP_MULTIPLY, 1, m, &cBinop_3qxFjXV8_sendMessage);
}

void Heavy_WSTD_EQ::cVar_K70tnFY0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_l1PLRDj8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_mrmCqZyC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_a6vpCrwn_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_69cqrMAA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9ieq6Bia_sendMessage);
}

void Heavy_WSTD_EQ::cVar_GgrixTeC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_NqfdLwVI_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Om2Zq2Ql_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_r0ANmhyM_sendMessage);
}

void Heavy_WSTD_EQ::cCast_jmTzalDt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_lA8Eubzx_sendMessage);
}

void Heavy_WSTD_EQ::cSend_qJf8gLKh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_PhD1oh29_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_qD1340gg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_KJBz6R2o_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_3cRiLGKb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ROoLJkoM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_p6u9OYmq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_uDoaCVmw_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_uDoaCVmw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_82lF8XfF, HV_BINOP_MULTIPLY, 1, m, &cBinop_82lF8XfF_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_82lF8XfF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_f1C9ddNa_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_f1C9ddNa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_3cRiLGKb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_l1PLRDj8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_KCEInLV2_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_KCEInLV2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PJmuOAz0_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xbO8UY1M_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Pds1VhFr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6jRMMuFj_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1US3xU1X_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JZ2IbmPb_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_F0sCoDh0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3kZyhQhS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_r5JwsTzS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WlnyT9XA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_LDMKW4E2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YNpGQPQu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_GhVnCHbz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_g14Ssnn2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_3qxFjXV8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fY1NJHgc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_iWrcyNtT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GgrixTeC, 1, m, &cVar_GgrixTeC_sendMessage);
}

void Heavy_WSTD_EQ::cCast_HHLZijH6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mrmCqZyC, 0, m, &cVar_mrmCqZyC_sendMessage);
}

void Heavy_WSTD_EQ::cCast_JZ2IbmPb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_F0sCoDh0, HV_BINOP_MULTIPLY, 0, m, &cBinop_F0sCoDh0_sendMessage);
}

void Heavy_WSTD_EQ::cCast_1US3xU1X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_r5JwsTzS, HV_BINOP_MULTIPLY, 0, m, &cBinop_r5JwsTzS_sendMessage);
}

void Heavy_WSTD_EQ::cCast_xbO8UY1M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3qxFjXV8, HV_BINOP_MULTIPLY, 0, m, &cBinop_3qxFjXV8_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Pds1VhFr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GhVnCHbz, HV_BINOP_MULTIPLY, 0, m, &cBinop_GhVnCHbz_sendMessage);
}

void Heavy_WSTD_EQ::cCast_PJmuOAz0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_6jRMMuFj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LDMKW4E2, HV_BINOP_MULTIPLY, 0, m, &cBinop_LDMKW4E2_sendMessage);
}

void Heavy_WSTD_EQ::cCast_9ieq6Bia_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_K70tnFY0, 0, m, &cVar_K70tnFY0_sendMessage);
}

void Heavy_WSTD_EQ::cCast_a6vpCrwn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GgrixTeC, 0, m, &cVar_GgrixTeC_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_SIRcOFtp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_uPRoKRJD, 1, m, &cIf_uPRoKRJD_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_ySWPHXxI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_6RSB1SRn, m);
}

void Heavy_WSTD_EQ::cBinop_0bDQmt97_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ySWPHXxI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_WfeFWxVz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_uPRoKRJD, 0, m, &cIf_uPRoKRJD_sendMessage);
}

void Heavy_WSTD_EQ::cSwitchcase_mFDdla3a_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_mZBjAowe, 0, m, &cSlice_mZBjAowe_sendMessage);
      break;
    }
    default: {
      cSwitchcase_xmK7aJXV_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_mZBjAowe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_IL0FwYpR_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_IL0FwYpR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_qBMhzFFC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_IL0FwYpR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_IL0FwYpR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_OMQSybL0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_s96Fqr7Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_R1vXKtgE_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_0UtEqoqx, 0, m, &cIf_0UtEqoqx_sendMessage);
}

void Heavy_WSTD_EQ::cIf_0UtEqoqx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_TvZfOHxY_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_N1aKhsEN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_8ML2gCYt_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_tYw1HkZx_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_VZ6vrjC2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_eEGy39ti, HV_BINOP_POW, 0, m, &cBinop_eEGy39ti_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_eEGy39ti_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_saYtiXHE, 0, m, &cIf_saYtiXHE_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_fIgsWAMy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_KrNfMpZC_sendMessage);
}

void Heavy_WSTD_EQ::cCast_xcuxBDot_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_N1aKhsEN, 0, m, &cIf_N1aKhsEN_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Tw95VNKu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_eFrxa5M3_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_eFrxa5M3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_N1aKhsEN, 1, m, &cIf_N1aKhsEN_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_tYw1HkZx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_fIgsWAMy_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_8ML2gCYt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_saYtiXHE, 0, m, &cIf_saYtiXHE_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_KrNfMpZC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eEGy39ti, HV_BINOP_POW, 1, m, &cBinop_eEGy39ti_sendMessage);
  cMsg_VZ6vrjC2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_saYtiXHE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_4N90wOJT, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_R1vXKtgE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0UtEqoqx, 1, m, &cIf_0UtEqoqx_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_TvZfOHxY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZPCKlTXA, HV_BINOP_GREATER_THAN, 1, m, &cBinop_ZPCKlTXA_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_EGTYLAKn, HV_BINOP_EQ, 1, m, &cBinop_EGTYLAKn_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_TCXFgzve_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_FQB7WwWv, HV_BINOP_ADD, 0, m, &cBinop_FQB7WwWv_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_FQB7WwWv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Tw95VNKu_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xcuxBDot_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ZPCKlTXA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_saYtiXHE, 1, m, &cIf_saYtiXHE_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_EGTYLAKn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6vqXlB2D_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_6vqXlB2D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_4N90wOJT, m);
}

void Heavy_WSTD_EQ::cCast_FDTV2AK1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FQB7WwWv, HV_BINOP_ADD, 1, m, &cBinop_FQB7WwWv_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZPCKlTXA, HV_BINOP_GREATER_THAN, 0, m, &cBinop_ZPCKlTXA_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_EGTYLAKn, HV_BINOP_EQ, 0, m, &cBinop_EGTYLAKn_sendMessage);
}

void Heavy_WSTD_EQ::cCast_aehEHtCn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TCXFgzve_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_VQxGYpQK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_s96Fqr7Y, 0, m, &cVar_s96Fqr7Y_sendMessage);
}

void Heavy_WSTD_EQ::cVar_eMjhq3vb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_yQf09ajf_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_QktBtJc3, 0, m, &cIf_QktBtJc3_sendMessage);
}

void Heavy_WSTD_EQ::cIf_QktBtJc3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_hvvWxsgO_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_BaOFXrbT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_yD8PGftt_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_NfgDeXdx_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_1PwQ0oxK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_LwqJV6lh, HV_BINOP_POW, 0, m, &cBinop_LwqJV6lh_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_LwqJV6lh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3PN28CfP, 0, m, &cIf_3PN28CfP_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_xh6UiQsM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_sctt6K4F_sendMessage);
}

void Heavy_WSTD_EQ::cCast_gKP27BMb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_hTjoSmQq_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Drt7L67e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BaOFXrbT, 0, m, &cIf_BaOFXrbT_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_hTjoSmQq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BaOFXrbT, 1, m, &cIf_BaOFXrbT_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_NfgDeXdx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_xh6UiQsM_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_yD8PGftt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_3PN28CfP, 0, m, &cIf_3PN28CfP_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_sctt6K4F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LwqJV6lh, HV_BINOP_POW, 1, m, &cBinop_LwqJV6lh_sendMessage);
  cMsg_1PwQ0oxK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_3PN28CfP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_iaTIc6C3_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_CLy7r0U7_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_f3mlegHy_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_yQf09ajf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QktBtJc3, 1, m, &cIf_QktBtJc3_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_hvvWxsgO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cg7iDwdG, HV_BINOP_GREATER_THAN, 1, m, &cBinop_cg7iDwdG_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_P2WOz98B, HV_BINOP_EQ, 1, m, &cBinop_P2WOz98B_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_nXJkehwv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_qxGU4vEG, HV_BINOP_ADD, 0, m, &cBinop_qxGU4vEG_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_qxGU4vEG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gKP27BMb_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Drt7L67e_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_cg7iDwdG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3PN28CfP, 1, m, &cIf_3PN28CfP_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_P2WOz98B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_y9BGHwoY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_y9BGHwoY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_iaTIc6C3_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_CLy7r0U7_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_f3mlegHy_sendMessage);
}

void Heavy_WSTD_EQ::cCast_mxyIEMke_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_eMjhq3vb, 0, m, &cVar_eMjhq3vb_sendMessage);
}

void Heavy_WSTD_EQ::cCast_a08Ix1gh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qxGU4vEG, HV_BINOP_ADD, 1, m, &cBinop_qxGU4vEG_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_cg7iDwdG, HV_BINOP_GREATER_THAN, 0, m, &cBinop_cg7iDwdG_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_P2WOz98B, HV_BINOP_EQ, 0, m, &cBinop_P2WOz98B_sendMessage);
}

void Heavy_WSTD_EQ::cCast_bSC581HO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nXJkehwv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_buzwHiRa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_r1yWoVjZ_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_m5xDDkXC, 0, m, &cIf_m5xDDkXC_sendMessage);
}

void Heavy_WSTD_EQ::cIf_m5xDDkXC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_ds8AAdIt_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_gBfm3WqP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_tvcXa7Gg_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_LRRnzXFm_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_iNufwB7Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ODu4ta5w, HV_BINOP_POW, 0, m, &cBinop_ODu4ta5w_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ODu4ta5w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Omf6faGA, 0, m, &cIf_Omf6faGA_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_JBlJ2XCw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_txvt30av_sendMessage);
}

void Heavy_WSTD_EQ::cCast_wA0oQ3TN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gBfm3WqP, 0, m, &cIf_gBfm3WqP_sendMessage);
}

void Heavy_WSTD_EQ::cCast_pxf2b0MP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ElkHX3bX_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ElkHX3bX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gBfm3WqP, 1, m, &cIf_gBfm3WqP_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_LRRnzXFm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_JBlJ2XCw_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_tvcXa7Gg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_Omf6faGA, 0, m, &cIf_Omf6faGA_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_txvt30av_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ODu4ta5w, HV_BINOP_POW, 1, m, &cBinop_ODu4ta5w_sendMessage);
  cMsg_iNufwB7Q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_Omf6faGA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_srCDZ4fI, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_r1yWoVjZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_m5xDDkXC, 1, m, &cIf_m5xDDkXC_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ds8AAdIt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qzcIBqra, HV_BINOP_GREATER_THAN, 1, m, &cBinop_qzcIBqra_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ffXoGqen, HV_BINOP_EQ, 1, m, &cBinop_ffXoGqen_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_gV2HrKzp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_PEZNuajI, HV_BINOP_ADD, 0, m, &cBinop_PEZNuajI_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_PEZNuajI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pxf2b0MP_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wA0oQ3TN_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_qzcIBqra_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Omf6faGA, 1, m, &cIf_Omf6faGA_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ffXoGqen_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_G4fhXOFZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_G4fhXOFZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_srCDZ4fI, m);
}

void Heavy_WSTD_EQ::cCast_SxkifzEe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gV2HrKzp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_EVb7Uhcc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_buzwHiRa, 0, m, &cVar_buzwHiRa_sendMessage);
}

void Heavy_WSTD_EQ::cCast_u9JOZ4jq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PEZNuajI, HV_BINOP_ADD, 1, m, &cBinop_PEZNuajI_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_qzcIBqra, HV_BINOP_GREATER_THAN, 0, m, &cBinop_qzcIBqra_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ffXoGqen, HV_BINOP_EQ, 0, m, &cBinop_ffXoGqen_sendMessage);
}

void Heavy_WSTD_EQ::cIf_i8Xhll1G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_Zitth5RP, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cSwitchcase_GalMsWyF_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_0osk0ODP, 0, m, &cSlice_0osk0ODP_sendMessage);
      break;
    }
    default: {
      cSwitchcase_GCVUoShn_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_0osk0ODP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_CdqzhjoW_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_CdqzhjoW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_wzM7NXEm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_CdqzhjoW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_CdqzhjoW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_nyfmk0CN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_GCVUoShn_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_kcI1v22g, 0, m, &cSlice_kcI1v22g_sendMessage);
      break;
    }
    default: {
      cSwitchcase_mFDdla3a_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_kcI1v22g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_dgV7q1Eg_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_dgV7q1Eg_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_6fB7BVMZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_dgV7q1Eg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_dgV7q1Eg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_gWG9L05L_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_xmK7aJXV_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_SSOX3hqx, 0, m, &cSlice_SSOX3hqx_sendMessage);
      break;
    }
    default: {
      cSwitchcase_EFNf7m83_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_SSOX3hqx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_C0LNXPNG_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_C0LNXPNG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_LFmLVSs3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_C0LNXPNG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_C0LNXPNG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_rTwu21dT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_EFNf7m83_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_F7ITdjNh, 0, m, &cSlice_F7ITdjNh_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_F7ITdjNh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_FRQVn6o8_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_FRQVn6o8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_YFmZEx9h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_FRQVn6o8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_FRQVn6o8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_5ew5tgZt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_xAsDsqfH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_n21IT7xM, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_h7GUhQ49_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VkHrLdWM, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_SzU2P1wa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PoGfAe9o, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_N0YdE8Eb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_oIApZuDw, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_Xou94jYJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_38rjjq8V, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_derRYGmp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_AXVCzlbX_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_AXVCzlbX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MWepctDF, HV_BINOP_DIVIDE, 1, m, &cBinop_MWepctDF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IUa690ZE_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_Rs0CtQP2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_xNXAAor9_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_VOKygGBC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_Rs0CtQP2_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_xNXAAor9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MWepctDF, HV_BINOP_DIVIDE, 0, m, &cBinop_MWepctDF_sendMessage);
}

void Heavy_WSTD_EQ::cCast_IUa690ZE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VOKygGBC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_MWepctDF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lLj7v8qK, HV_BINOP_MULTIPLY, 1, m, &cBinop_lLj7v8qK_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_lLj7v8qK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_l5NnPEPF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XQ7pouKt_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_FYusVm5F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_0Y4ZnXyk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_SWOC5R5h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_gHccN9bS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_NTc81FrC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_bsmky5zd_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_bsmky5zd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lLj7v8qK, HV_BINOP_MULTIPLY, 0, m, &cBinop_lLj7v8qK_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Rxv6Ex2z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_iqRdL6uz_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_iqRdL6uz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tcGAjip6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_D1K8yMsb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2pmbgLt6, 1, m, &cVar_2pmbgLt6_sendMessage);
}

void Heavy_WSTD_EQ::cVar_2pmbgLt6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wJMRVVED_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_qhbgxsBO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vSO7YxFl, HV_BINOP_MULTIPLY, 1, m, &cBinop_vSO7YxFl_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_qJCRY9Hm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_qhbgxsBO_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_PKF4tSwT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Q8QdOmHk_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Q8QdOmHk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_07aZ3xSC, HV_BINOP_MULTIPLY, 1, m, &cBinop_07aZ3xSC_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ObBnsshS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_soQaf0aE, HV_BINOP_MULTIPLY, 1, m, &cBinop_soQaf0aE_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_QveJcD18_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_ObBnsshS_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_fmUuOjdD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zuVPgocx, HV_BINOP_MULTIPLY, 1, m, &cBinop_zuVPgocx_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_uXm4Wjzm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_6zzi6dxv_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_6zzi6dxv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uXSqeMtX, HV_BINOP_MULTIPLY, 1, m, &cBinop_uXSqeMtX_sendMessage);
}

void Heavy_WSTD_EQ::cVar_ioIvo1FM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NpmeCTie_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_NTc81FrC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FT3wKDRJ_sendMessage);
}

void Heavy_WSTD_EQ::cVar_W9DYCqak_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_Rxv6Ex2z_sendMessage);
}

void Heavy_WSTD_EQ::cCast_l5NnPEPF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_FYusVm5F_sendMessage);
}

void Heavy_WSTD_EQ::cCast_XQ7pouKt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_SWOC5R5h_sendMessage);
}

void Heavy_WSTD_EQ::cSend_0Y4ZnXyk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_DKIUnUw1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_gHccN9bS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ydDAs9Sk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_xd41tbze_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_irnHOs7T_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_tcGAjip6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_hHsQoDlj_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_hHsQoDlj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_s32cNjAp, HV_BINOP_MULTIPLY, 1, m, &cBinop_s32cNjAp_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_s32cNjAp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_sf5TxeLF_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_sf5TxeLF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_xd41tbze_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_wJMRVVED_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_BTzlcIiy_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_BTzlcIiy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RpPcTxZi_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dPTesVBF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RsTwUCow_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IYCne8LG_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4C37Jxqt_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UufwWwuD_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_vSO7YxFl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xAsDsqfH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_07aZ3xSC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_h7GUhQ49_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_soQaf0aE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SzU2P1wa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_zuVPgocx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_N0YdE8Eb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_uXSqeMtX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Xou94jYJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_eUooTLAg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ioIvo1FM, 0, m, &cVar_ioIvo1FM_sendMessage);
}

void Heavy_WSTD_EQ::cCast_UWJJ65CE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_W9DYCqak, 1, m, &cVar_W9DYCqak_sendMessage);
}

void Heavy_WSTD_EQ::cCast_IYCne8LG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_soQaf0aE, HV_BINOP_MULTIPLY, 0, m, &cBinop_soQaf0aE_sendMessage);
}

void Heavy_WSTD_EQ::cCast_RsTwUCow_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zuVPgocx, HV_BINOP_MULTIPLY, 0, m, &cBinop_zuVPgocx_sendMessage);
}

void Heavy_WSTD_EQ::cCast_RpPcTxZi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_UufwWwuD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vSO7YxFl, HV_BINOP_MULTIPLY, 0, m, &cBinop_vSO7YxFl_sendMessage);
}

void Heavy_WSTD_EQ::cCast_4C37Jxqt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_07aZ3xSC, HV_BINOP_MULTIPLY, 0, m, &cBinop_07aZ3xSC_sendMessage);
}

void Heavy_WSTD_EQ::cCast_dPTesVBF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uXSqeMtX, HV_BINOP_MULTIPLY, 0, m, &cBinop_uXSqeMtX_sendMessage);
}

void Heavy_WSTD_EQ::cCast_FT3wKDRJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2pmbgLt6, 0, m, &cVar_2pmbgLt6_sendMessage);
}

void Heavy_WSTD_EQ::cCast_NpmeCTie_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_W9DYCqak, 0, m, &cVar_W9DYCqak_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_m3VT5c0K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_N33r8JzP, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_KMudWsOz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_S9tdCYTt, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_Ycl02LuI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_OU2cm6c0, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_Gt0wzCJb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_OW6TchOY, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_8BL6Z7uk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_0aqqeUGz_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_0aqqeUGz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Cx6Ji2JL, HV_BINOP_DIVIDE, 1, m, &cBinop_Cx6Ji2JL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vhtdinwm_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_ldXedTk3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_qNrIQkTA_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_ccFpG7vg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_ldXedTk3_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_qNrIQkTA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Cx6Ji2JL, HV_BINOP_DIVIDE, 0, m, &cBinop_Cx6Ji2JL_sendMessage);
}

void Heavy_WSTD_EQ::cCast_vhtdinwm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ccFpG7vg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_Cx6Ji2JL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vk7ob8iC, HV_BINOP_MULTIPLY, 1, m, &cBinop_vk7ob8iC_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_vk7ob8iC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sEv6Lruu_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eP0zHqGs_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_9V1SFUgG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_YFtgSocn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_J1nAjF7w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_6ZOFUI8v_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_iwJistND_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_wk9S8vkT_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_wk9S8vkT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vk7ob8iC, HV_BINOP_MULTIPLY, 0, m, &cBinop_vk7ob8iC_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Eai4xSnJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_WBNxl0bB_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_WBNxl0bB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yP5vzJK3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_uBYfOf2h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Uia92skq, HV_BINOP_MULTIPLY, 1, m, &cBinop_Uia92skq_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_5ioWtita_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OpffUeFH, 1, m, &cVar_OpffUeFH_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_0jGxivMa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RLRK1eeh, HV_BINOP_MULTIPLY, 1, m, &cBinop_RLRK1eeh_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_OW3wh8AH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_RgioInnO_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_RgioInnO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DZyvqVN0, HV_BINOP_MULTIPLY, 1, m, &cBinop_DZyvqVN0_sendMessage);
}

void Heavy_WSTD_EQ::cVar_OpffUeFH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JSrwwUkg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_DxXIdD1J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ps54NNXH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_iwJistND_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_905jefQu_sendMessage);
}

void Heavy_WSTD_EQ::cVar_0WyaBhBa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_Eai4xSnJ_sendMessage);
}

void Heavy_WSTD_EQ::cCast_sEv6Lruu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_9V1SFUgG_sendMessage);
}

void Heavy_WSTD_EQ::cCast_eP0zHqGs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_J1nAjF7w_sendMessage);
}

void Heavy_WSTD_EQ::cSend_YFtgSocn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_KWec98DY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_6ZOFUI8v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_0HRWsFTx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_cqff1IB7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_9RjakxEg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_yP5vzJK3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_2PSP8ygP_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_2PSP8ygP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KEchSdQX, HV_BINOP_MULTIPLY, 1, m, &cBinop_KEchSdQX_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_KEchSdQX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_4JtNtUCD_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_4JtNtUCD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_cqff1IB7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_JSrwwUkg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_51Ki0bT8_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_51Ki0bT8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JyTUeREY_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Q72d50yJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OvvtjMzv_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SctBjSg9_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_V7GionD3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_m3VT5c0K_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_Uia92skq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KMudWsOz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_RLRK1eeh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ycl02LuI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_DZyvqVN0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Gt0wzCJb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_DiWklaR8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_DxXIdD1J, 0, m, &cVar_DxXIdD1J_sendMessage);
}

void Heavy_WSTD_EQ::cCast_SuN38qVi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0WyaBhBa, 1, m, &cVar_0WyaBhBa_sendMessage);
}

void Heavy_WSTD_EQ::cCast_905jefQu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OpffUeFH, 0, m, &cVar_OpffUeFH_sendMessage);
}

void Heavy_WSTD_EQ::cCast_ps54NNXH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0WyaBhBa, 0, m, &cVar_0WyaBhBa_sendMessage);
}

void Heavy_WSTD_EQ::cCast_JyTUeREY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DZyvqVN0, HV_BINOP_MULTIPLY, 0, m, &cBinop_DZyvqVN0_sendMessage);
}

void Heavy_WSTD_EQ::cCast_SctBjSg9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_V7GionD3, HV_BINOP_MULTIPLY, 0, m, &cBinop_V7GionD3_sendMessage);
}

void Heavy_WSTD_EQ::cCast_OvvtjMzv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Uia92skq, HV_BINOP_MULTIPLY, 0, m, &cBinop_Uia92skq_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Q72d50yJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RLRK1eeh, HV_BINOP_MULTIPLY, 0, m, &cBinop_RLRK1eeh_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_JD3RfyJw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_I1SA4Qnp, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_sNZFMMrN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Ru5ZnYDn, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_g3btHUD2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IOK5ADZF, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_Wi5Jc3t3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XS90AB2o, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_J5rRSCab_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZtgnT8Ns, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_H97MfuJa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_EjnNjEi3_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_EjnNjEi3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lR7evhiP, HV_BINOP_DIVIDE, 1, m, &cBinop_lR7evhiP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FZW6ueP1_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_EMIMTjnS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_yJUYWjyd_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_llTj9mUE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_EMIMTjnS_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_yJUYWjyd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lR7evhiP, HV_BINOP_DIVIDE, 0, m, &cBinop_lR7evhiP_sendMessage);
}

void Heavy_WSTD_EQ::cCast_FZW6ueP1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_llTj9mUE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_lR7evhiP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EAOwZT9h, HV_BINOP_MULTIPLY, 1, m, &cBinop_EAOwZT9h_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_EAOwZT9h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gJ8XYS5P_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zpDXF1FN_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_vgWyUnKH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_umPaMaq8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_q9zWVoyJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_jRbmfVhq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_rtgRtGYT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_RquOJhwB_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_RquOJhwB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EAOwZT9h, HV_BINOP_MULTIPLY, 0, m, &cBinop_EAOwZT9h_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_CLdn85uN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_ch1s3K4G_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ch1s3K4G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0owSTAzm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_6SnKyNt8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qqqcSjmQ, HV_BINOP_MULTIPLY, 1, m, &cBinop_qqqcSjmQ_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_PDJXouIw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_hw0VDtov_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_hw0VDtov_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_6SnKyNt8_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_TfIlfNrQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_rEXdpfxP_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_rEXdpfxP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qJhAdLgk, HV_BINOP_MULTIPLY, 1, m, &cBinop_qJhAdLgk_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_XbkMpRgS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_41VL5Yyo, HV_BINOP_MULTIPLY, 1, m, &cBinop_41VL5Yyo_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_vPbNY86p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_dPAEMOQS_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_dPAEMOQS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_XbkMpRgS_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_6agWvasl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TJ5ZW4WT, 1, m, &cVar_TJ5ZW4WT_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_m8AudxGe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IOX12d79, HV_BINOP_MULTIPLY, 1, m, &cBinop_IOX12d79_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_heOPwZRx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_yjOJovEK_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_yjOJovEK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_g0lNx2aq, HV_BINOP_MULTIPLY, 1, m, &cBinop_g0lNx2aq_sendMessage);
}

void Heavy_WSTD_EQ::cVar_TJ5ZW4WT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ix6HGrao_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_omBPw5CU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7a1QweeK_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_rtgRtGYT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZY6gIDQn_sendMessage);
}

void Heavy_WSTD_EQ::cVar_dR5B16kh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_CLdn85uN_sendMessage);
}

void Heavy_WSTD_EQ::cCast_zpDXF1FN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_q9zWVoyJ_sendMessage);
}

void Heavy_WSTD_EQ::cCast_gJ8XYS5P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_vgWyUnKH_sendMessage);
}

void Heavy_WSTD_EQ::cSend_umPaMaq8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_evo528rf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_jRbmfVhq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_m6OW6Xo7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_i4flElBG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_AgzqzONz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_0owSTAzm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_BOsMN1H0_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_BOsMN1H0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vt1hhqpm, HV_BINOP_MULTIPLY, 1, m, &cBinop_vt1hhqpm_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_vt1hhqpm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_qKWEvALE_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_qKWEvALE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_i4flElBG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_Ix6HGrao_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_A0Dnbpkm_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_A0Dnbpkm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YjOt4s9U_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vYPef9lm_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RIDLAVzg_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_quzfbB5q_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZLaPYWyF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_g6MBSRDf_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_qqqcSjmQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JD3RfyJw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_qJhAdLgk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sNZFMMrN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_41VL5Yyo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_g3btHUD2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_IOX12d79_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Wi5Jc3t3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_g0lNx2aq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_J5rRSCab_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_Jt3FmUGf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_omBPw5CU, 0, m, &cVar_omBPw5CU_sendMessage);
}

void Heavy_WSTD_EQ::cCast_OLpKwbma_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dR5B16kh, 1, m, &cVar_dR5B16kh_sendMessage);
}

void Heavy_WSTD_EQ::cCast_vYPef9lm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_g0lNx2aq, HV_BINOP_MULTIPLY, 0, m, &cBinop_g0lNx2aq_sendMessage);
}

void Heavy_WSTD_EQ::cCast_g6MBSRDf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qqqcSjmQ, HV_BINOP_MULTIPLY, 0, m, &cBinop_qqqcSjmQ_sendMessage);
}

void Heavy_WSTD_EQ::cCast_quzfbB5q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_41VL5Yyo, HV_BINOP_MULTIPLY, 0, m, &cBinop_41VL5Yyo_sendMessage);
}

void Heavy_WSTD_EQ::cCast_RIDLAVzg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IOX12d79, HV_BINOP_MULTIPLY, 0, m, &cBinop_IOX12d79_sendMessage);
}

void Heavy_WSTD_EQ::cCast_ZLaPYWyF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qJhAdLgk, HV_BINOP_MULTIPLY, 0, m, &cBinop_qJhAdLgk_sendMessage);
}

void Heavy_WSTD_EQ::cCast_YjOt4s9U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_ZY6gIDQn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TJ5ZW4WT, 0, m, &cVar_TJ5ZW4WT_sendMessage);
}

void Heavy_WSTD_EQ::cCast_7a1QweeK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dR5B16kh, 0, m, &cVar_dR5B16kh_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_iaTIc6C3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_i8Xhll1G, 1, m, &cIf_i8Xhll1G_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_CaeUh7A0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Zitth5RP, m);
}

void Heavy_WSTD_EQ::cBinop_CLy7r0U7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CaeUh7A0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_f3mlegHy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_i8Xhll1G, 0, m, &cIf_i8Xhll1G_sendMessage);
}

void Heavy_WSTD_EQ::cVar_mezVTrpt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AytiXOSh, HV_BINOP_DIVIDE, 0, m, &cBinop_AytiXOSh_sendMessage);
}

void Heavy_WSTD_EQ::cVar_QevFZ6Ee_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SFLuNZUG, HV_BINOP_DIVIDE, 1, m, &cBinop_SFLuNZUG_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_AytiXOSh, HV_BINOP_DIVIDE, 1, m, &cBinop_AytiXOSh_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_ZMvUJXBu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9HStPx6q, HV_BINOP_DIVIDE, 0, m, &cBinop_9HStPx6q_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_tji7FKux_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9HStPx6q, HV_BINOP_DIVIDE, 1, m, &cBinop_9HStPx6q_sendMessage);
}

void Heavy_WSTD_EQ::cCast_dY8TYEJy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QevFZ6Ee, 0, m, &cVar_QevFZ6Ee_sendMessage);
}

void Heavy_WSTD_EQ::cCast_EN8CKgBY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mezVTrpt, 0, m, &cVar_mezVTrpt_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Uu3mqARN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SFLuNZUG, HV_BINOP_DIVIDE, 0, m, &cBinop_SFLuNZUG_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_SFLuNZUG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_ZMvUJXBu_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_AytiXOSh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_tji7FKux_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_9HStPx6q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_7gena98t_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_8LbWcjIV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_VZe160ze_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_GArH79sx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_SsfIyfmc_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_7gena98t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_GArH79sx_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_SsfIyfmc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_8LbWcjIV_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_VZe160ze_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aQeEv5s6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_txTDRzUZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_miXh3fzr_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_GalMsWyF_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_vfG3B1Lt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_miXh3fzr_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_GalMsWyF_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_nMqphuRI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_miXh3fzr_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_GalMsWyF_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_A2SvJvdF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_miXh3fzr_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_GalMsWyF_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_aQeEv5s6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_miXh3fzr_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_GalMsWyF_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_7bNrDPTv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_RppIX3ln, 0, m, &cVar_RppIX3ln_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_udw4qyMA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_PWJqKuvd, 0, m, &cVar_PWJqKuvd_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_1P2bf5un, 0, m, &cVar_1P2bf5un_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Jmqtqx4g, 0, m, &cVar_Jmqtqx4g_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_lmIyhjpD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PWJqKuvd, 0, m, &cVar_PWJqKuvd_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_E3ULjbgs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1P2bf5un, 0, m, &cVar_1P2bf5un_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_l5bvAFjw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Jmqtqx4g, 0, m, &cVar_Jmqtqx4g_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_KQI44Wav_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JHkNQcJ7, 0, m, &cVar_JHkNQcJ7_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_4NDH9WhX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_C223am0Z_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VTYzPGdA_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_Q1kIgb6g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BPi11I13_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_29bHStIy_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GsBBdmJO_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_63EgB63m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lxmy60Bu_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nFnpfDVf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xpyccycD_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_DN6xj3M2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UxQeHFcg_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UZ1kiLqE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kdtbrG6R_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_O2np1h8U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_koBq9WKi_sendMessage(_c, 0, m);
  cMsg_v9WuaQq3_sendMessage(_c, 0, m);
  cMsg_Hik5Os4x_sendMessage(_c, 0, m);
  cMsg_derRYGmp_sendMessage(_c, 0, m);
  cMsg_8BL6Z7uk_sendMessage(_c, 0, m);
  cMsg_H97MfuJa_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_y8I1N6EF, 0, m, &cVar_y8I1N6EF_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_JHkNQcJ7, 0, m, &cVar_JHkNQcJ7_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_mrmCqZyC, 0, m, &cVar_mrmCqZyC_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ioIvo1FM, 0, m, &cVar_ioIvo1FM_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_DxXIdD1J, 0, m, &cVar_DxXIdD1J_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_omBPw5CU, 0, m, &cVar_omBPw5CU_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_BKPojZDl, 0, m, &cVar_BKPojZDl_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Uq9Nxydp, 0, m, &cVar_Uq9Nxydp_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_5gHgH7rf, 0, m, &cVar_5gHgH7rf_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Hs24rtUk, 0, m, &cVar_Hs24rtUk_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_9ZJ9yCuO, 0, m, &cVar_9ZJ9yCuO_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_kFBTKeDq, 0, m, &cVar_kFBTKeDq_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_kGWrsWMl, 0, m, &cVar_kGWrsWMl_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_j8IM3GUT, 0, m, &cVar_j8IM3GUT_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_qBMhzFFC, 0, m, &cVar_qBMhzFFC_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_s96Fqr7Y, 0, m, &cVar_s96Fqr7Y_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_eMjhq3vb, 0, m, &cVar_eMjhq3vb_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_buzwHiRa, 0, m, &cVar_buzwHiRa_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_wzM7NXEm, 0, m, &cVar_wzM7NXEm_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_6fB7BVMZ, 0, m, &cVar_6fB7BVMZ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_LFmLVSs3, 0, m, &cVar_LFmLVSs3_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_YFmZEx9h, 0, m, &cVar_YFmZEx9h_sendMessage);
  cMsg_udw4qyMA_sendMessage(_c, 0, m);
  cMsg_7bNrDPTv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_5u6IDSbd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iFlSXTlc, HV_BINOP_MULTIPLY, 0, m, &cBinop_iFlSXTlc_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_CkCjF9CE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_b6zFpDn0_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_gHfSNQxB_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_qInCdKXv_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_nqf4vY32_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_1IhmA9Rr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_sz2w5avU_sendMessage);
  cMsg_9N4O6wZO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_g9jdBfYs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ExjYmQyh, HV_BINOP_MULTIPLY, 0, m, &cBinop_ExjYmQyh_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_GEu8KeGK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_ChJoGFEz_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_wsjZCEps_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5qp36wL2, HV_BINOP_MULTIPLY, 1, m, &cBinop_5qp36wL2_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_ivKVU9hU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_M2YeMXmy_sendMessage);
  cMsg_fK4DeXBp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_PhD1oh29_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_82lF8XfF, HV_BINOP_MULTIPLY, 0, m, &cBinop_82lF8XfF_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_KJBz6R2o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_y9vHIOBi_sendMessage(_c, 0, m);
  cMsg_5gIlEmJN_sendMessage(_c, 0, m);
  cMsg_JoduXMLD_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_V87I52Nm_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_ROoLJkoM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_OoGuCtkT_sendMessage);
  cMsg_mFigPqak_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_OMQSybL0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_DxXIdD1J, 0, m, &cVar_DxXIdD1J_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_5ew5tgZt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SuN38qVi_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DiWklaR8_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_nyfmk0CN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VQxGYpQK_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FDTV2AK1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aehEHtCn_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_rTwu21dT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EVb7Uhcc_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_u9JOZ4jq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SxkifzEe_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_gWG9L05L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mxyIEMke_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_a08Ix1gh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bSC581HO_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_DKIUnUw1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_s32cNjAp, HV_BINOP_MULTIPLY, 0, m, &cBinop_s32cNjAp_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_ydDAs9Sk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_qJCRY9Hm_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_PKF4tSwT_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_QveJcD18_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_fmUuOjdD_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_irnHOs7T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_D1K8yMsb_sendMessage);
  cMsg_uXm4Wjzm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_KWec98DY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KEchSdQX, HV_BINOP_MULTIPLY, 0, m, &cBinop_KEchSdQX_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_0HRWsFTx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_0jGxivMa_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_9RjakxEg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_V7GionD3, HV_BINOP_MULTIPLY, 1, m, &cBinop_V7GionD3_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_uBYfOf2h_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_5ioWtita_sendMessage);
  cMsg_OW3wh8AH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_evo528rf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vt1hhqpm, HV_BINOP_MULTIPLY, 0, m, &cBinop_vt1hhqpm_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_m6OW6Xo7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PDJXouIw_sendMessage(_c, 0, m);
  cMsg_TfIlfNrQ_sendMessage(_c, 0, m);
  cMsg_vPbNY86p_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_m8AudxGe_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_AgzqzONz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_6agWvasl_sendMessage);
  cMsg_heOPwZRx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_qPsdW7rX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RppIX3ln, 0, m, &cVar_RppIX3ln_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_EQ::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_varread_f(&sVarf_noAa11p8, VOf(Bf0));
    __hv_varread_f(&sVarf_Z8gCX7Mw, VOf(Bf1));
    __hv_varread_f(&sVarf_5jUX3DNo, VOf(Bf2));
    __hv_add_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf0), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_XC7Tq37K, VOf(Bf0));
    __hv_varread_f(&sVarf_QGotOAlW, VOf(Bf1));
    __hv_varread_f(&sVarf_ZNM4X2xO, VOf(Bf3));
    __hv_add_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf0), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_F0pfxQUH, VOf(Bf0));
    __hv_line_f(&sLine_4EnoI1AL, VOf(Bf1));
    __hv_line_f(&sLine_9ge2iIPH, VOf(Bf4));
    __hv_line_f(&sLine_lO62bxDT, VOf(Bf5));
    __hv_line_f(&sLine_58g3Fyex, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_AjhaGbo9, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf4), VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_tPJPPdvD, VOf(Bf5));
    __hv_mul_f(VIf(Bf6), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_30vq1ArQ, VOf(Bf6));
    __hv_zero_f(VOf(Bf4));
    __hv_line_f(&sLine_O7QGTsjy, VOf(Bf1));
    __hv_line_f(&sLine_jt2yYbaq, VOf(Bf0));
    __hv_line_f(&sLine_tNY5afrE, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_yKi9Z4Yb, VIf(I0), VIf(Bf6), VIf(Bf4), VIf(Bf1), VIf(Bf0), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_6RSB1SRn, VOf(Bf0));
    __hv_mul_f(VIf(Bf7), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_gmK9OJ85, VOf(Bf7));
    __hv_line_f(&sLine_mQCh7H4q, VOf(Bf1));
    __hv_line_f(&sLine_84qXi3tg, VOf(Bf4));
    __hv_line_f(&sLine_hcXInn9f, VOf(Bf6));
    __hv_line_f(&sLine_DoswGbd4, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_2mXiAR0Q, VIf(I0), VIf(Bf7), VIf(Bf1), VIf(Bf4), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_Cq61F8ZE, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_noAa11p8, VIf(Bf5));
    __hv_varwrite_f(&sVarf_Z8gCX7Mw, VIf(Bf0));
    __hv_varwrite_f(&sVarf_5jUX3DNo, VIf(Bf6));
    __hv_line_f(&sLine_n21IT7xM, VOf(Bf6));
    __hv_line_f(&sLine_VkHrLdWM, VOf(Bf0));
    __hv_line_f(&sLine_PoGfAe9o, VOf(Bf5));
    __hv_line_f(&sLine_oIApZuDw, VOf(Bf8));
    __hv_line_f(&sLine_38rjjq8V, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_1W4ElH8U, VIf(I1), VIf(Bf6), VIf(Bf0), VIf(Bf5), VIf(Bf8), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_4N90wOJT, VOf(Bf8));
    __hv_mul_f(VIf(Bf4), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_N33r8JzP, VOf(Bf4));
    __hv_zero_f(VOf(Bf5));
    __hv_line_f(&sLine_S9tdCYTt, VOf(Bf0));
    __hv_line_f(&sLine_OU2cm6c0, VOf(Bf6));
    __hv_line_f(&sLine_OW6TchOY, VOf(Bf1));
    __hv_biquad_f(&sBiquad_s_DfovUTHu, VIf(I1), VIf(Bf4), VIf(Bf5), VIf(Bf0), VIf(Bf6), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_Zitth5RP, VOf(Bf6));
    __hv_mul_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_I1SA4Qnp, VOf(Bf1));
    __hv_line_f(&sLine_Ru5ZnYDn, VOf(Bf0));
    __hv_line_f(&sLine_IOK5ADZF, VOf(Bf5));
    __hv_line_f(&sLine_XS90AB2o, VOf(Bf4));
    __hv_line_f(&sLine_ZtgnT8Ns, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_wb5826pH, VIf(I1), VIf(Bf1), VIf(Bf0), VIf(Bf5), VIf(Bf4), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_srCDZ4fI, VOf(Bf4));
    __hv_mul_f(VIf(Bf7), VIf(Bf4), VOf(Bf4));
    __hv_varwrite_f(&sVarf_XC7Tq37K, VIf(Bf8));
    __hv_varwrite_f(&sVarf_QGotOAlW, VIf(Bf6));
    __hv_varwrite_f(&sVarf_ZNM4X2xO, VIf(Bf4));
    __hv_add_f(VIf(Bf3), VIf(O1), VOf(O1));
    __hv_add_f(VIf(Bf2), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_EQ::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_EQ::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
